% Auto-generated chapter 12 for abudawud
% Hadiths in this chapter: 129

\hadithdefcmd{abudawud}{2046}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، قَالَ إِنِّي لأَمْشِي مَعَ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ بِمِنًى إِذْ لَقِيَهُ عُثْمَانُ فَاسْتَخْلاَهُ فَلَمَّا رَأَى عَبْدُ اللَّهِ أَنْ لَيْسَتْ لَهُ حَاجَةٌ قَالَ لِي تَعَالَ يَا عَلْقَمَةُ فَجِئْتُ فَقَالَ لَهُ عُثْمَانُ أَلاَ نُزَوِّجُكَ يَا أَبَا عَبْدِ الرَّحْمَنِ بِجَارِيَةٍ بِكْرٍ لَعَلَّهُ يَرْجِعُ إِلَيْكَ مِنْ نَفْسِكَ مَا كُنْتَ تَعْهَدُ فَقَالَ عَبْدُ اللَّهِ لَئِنْ قُلْتَ ذَاكَ لَقَدْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ اسْتَطَاعَ مِنْكُمُ الْبَاءَةَ فَلْيَتَزَوَّجْ فَإِنَّهُ أَغَضُّ لِلْبَصَرِ وَأَحْصَنُ لِلْفَرْجِ وَمَنْ لَمْ يَسْتَطِعْ مِنْكُمْ فَعَلَيْهِ بِالصَّوْمِ فَإِنَّهُ لَهُ وِجَاءٌ ‏"‏ ‏.‏\hadithno{2046}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1905) Sahih Muslim (1400)}\hadithtrans{‘Alqamah said “I was going with ‘Abd Allaah bin Mas’ud at Mina where ‘Uthman met him and desired to have a talk with him in privacy”. When ‘Abd Allaah (bin Mas’ud) thought there was no need of privacy, he said to me “Come, ‘Alqamah So I came (to him)”. Then ‘Uthman said to him “Should we not marry you, Abu ‘Abd Al Rahman to a virgin girl, so that the power you have lost may return to you?” ‘Abd Allaah (bin Mas’ud) said “If you say that , I heard the Apostle of Allaah(ﷺ) say “ Those of you who can support a wife, should marry, for it keeps you from looking at strange women and preserve from unlawful intercourse, but those who cannot should devote themselves to fasting, for it is a means of suppressing sexual desire}}
\hadithdefcmd{abudawud}{2047}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، - يَعْنِي ابْنَ سَعِيدٍ - حَدَّثَنِي عُبَيْدُ اللَّهِ، حَدَّثَنِي سَعِيدُ بْنُ أَبِي سَعِيدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ تُنْكَحُ النِّسَاءُ لأَرْبَعٍ لِمَالِهَا وَلِحَسَبِهَا وَلِجَمَالِهَا وَلِدِينِهَا فَاظْفَرْ بِذَاتِ الدِّينِ تَرِبَتْ يَدَاكَ ‏"‏ ‏.‏\hadithno{2047}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5090) Sahih Muslim (1466)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “Women may be married for four reasons:for her property, her ranks, her beauty and her religiosity. So get the one who is religious and prosper (lit. may your hands cleave to the dust).”}}
\hadithdefcmd{abudawud}{2048}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، أَخْبَرَنَا الأَعْمَشُ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ لِي رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَتَزَوَّجْتَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ بِكْرًا أَمْ ثَيِّبًا ‏"‏ ‏.‏ فَقُلْتُ ثَيِّبًا ‏.‏ قَالَ ‏"‏ أَفَلاَ بِكْرٌ تُلاَعِبُهَا وَتُلاَعِبُكَ ‏"‏ ‏.‏\hadithno{2048}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Jabir bin ‘Abd Allah said “The Apostle of Allaah(ﷺ) said to me “Did you marry?” I said “Yes”. He again said “Virgin or Non Virgin (woman previously married)?” I said “Non Virgin”. He said “Why (did you) not (marry) a virgin with whom you could sport and she could sport with you}}
\hadithdefcmd{abudawud}{2049}{قَالَ أَبُو دَاوُدَ كَتَبَ إِلَىَّ حُسَيْنُ بْنُ حُرَيْثٍ الْمَرْوَزِيُّ حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ عُمَارَةَ بْنِ أَبِي حَفْصَةَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنَّ امْرَأَتِي لاَ تَمْنَعُ يَدَ لاَمِسٍ ‏.‏ قَالَ ‏"‏ غَرِّبْهَا ‏"‏ ‏.‏ قَالَ أَخَافُ أَنْ تَتْبَعَهَا نَفْسِي ‏.‏ قَالَ ‏"‏ فَاسْتَمْتِعْ بِهَا ‏"‏ ‏.‏\hadithno{2049}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: A man came to the Prophet (ﷺ), and said: My wife does not prevent the hand of a man who touches her. He said: Divorce her. He then said: I am afraid my inner self may covet her. He said: Then enjoy her}}
\hadithdefcmd{abudawud}{2050}{حَدَّثَنَا أَحْمَدُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا مُسْتَلِمُ بْنُ سَعِيدِ ابْنُ أُخْتِ، مَنْصُورِ بْنِ زَاذَانَ عَنْ مَنْصُورٍ، - يَعْنِي ابْنَ زَاذَانَ - عَنْ مُعَاوِيَةَ بْنِ قُرَّةَ، عَنْ مَعْقِلِ بْنِ يَسَارٍ، قَالَ جَاءَ رَجُلٌ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقَالَ إِنِّي أَصَبْتُ امْرَأَةً ذَاتَ حَسَبٍ وَجَمَالٍ وَإِنَّهَا لاَ تَلِدُ أَفَأَتَزَوَّجُهَا قَالَ ‏"‏ لاَ ‏"‏ ‏.‏ ثُمَّ أَتَاهُ الثَّانِيَةَ فَنَهَاهُ ثُمَّ أَتَاهُ الثَّالِثَةَ فَقَالَ ‏"‏ تَزَوَّجُوا الْوَدُودَ الْوَلُودَ فَإِنِّي مُكَاثِرٌ بِكُمُ الأُمَمَ ‏"‏ ‏.‏\hadithno{2050}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ma'qil ibn Yasar: A man came to the Prophet (ﷺ) and said: I have found a woman of rank and beauty, but she does not give birth to children. Should I marry her? He said: No. He came again to him, but he prohibited him. He came to him third time, and he (the Prophet) said: Marry women who are loving and very prolific, for I shall outnumber the peoples by you}}
\hadithdefcmd{abudawud}{2051}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ مُحَمَّدٍ التَّيْمِيُّ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ بْنِ الأَخْنَسِ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ مَرْثَدَ بْنَ أَبِي مَرْثَدٍ الْغَنَوِيَّ، كَانَ يَحْمِلُ الأُسَارَى بِمَكَّةَ وَكَانَ بِمَكَّةَ بَغِيٌّ يُقَالُ لَهَا عَنَاقُ وَكَانَتْ صَدِيقَتَهُ قَالَ جِئْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَنْكِحُ عَنَاقَ قَالَ فَسَكَتَ عَنِّي فَنَزَلَتْ ‏\{‏ وَالزَّانِيَةُ لاَ يَنْكِحُهَا إِلاَّ زَانٍ أَوْ مُشْرِكٌ ‏\}‏ فَدَعَانِي فَقَرَأَهَا عَلَىَّ وَقَالَ ‏"‏ لاَ تَنْكِحْهَا ‏"‏ ‏.‏\hadithno{2051}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abdullah ibn Amr ibn al-'As: Marthad ibn AbuMarthad al-Ghanawi used to take prisoners (of war) from Mecca (to Medina). At Mecca there was a prostitute called Inaq who had illicit relations with him. (Marthad said:) I came to the Prophet (ﷺ) and said to him: May I marry Inaq, Messenger of Allah? The narrator said: He kept silence towards me. Then the verse was revealed:"....and the adulteress none shall marry save and adulterer or an idolater." He called me and recited this (verse) to me, and said: Do not marry her}}
\hadithdefcmd{abudawud}{2052}{حَدَّثَنَا مُسَدَّدٌ، وَأَبُو مَعْمَرٍ قَالاَ حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ حَبِيبٍ، حَدَّثَنِي عَمْرُو بْنُ شُعَيْبٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَنْكِحُ الزَّانِي الْمَجْلُودُ إِلاَّ مِثْلَهُ ‏"‏ ‏.‏ وَقَالَ أَبُو مَعْمَرٍ حَدَّثَنِي حَبِيبٌ الْمُعَلِّمُ عَنْ عَمْرِو بْنِ شُعَيْبٍ ‏.‏\hadithno{2052}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: The adulterer who has been flogged shall not marry save the one like him. AbuMa'mar said: Habib al-Mu'allim narrated (this tradition) to us on the authority of Amr ibn Shu'ayb}}
\hadithdefcmd{abudawud}{2053}{حَدَّثَنَا هَنَّادُ بْنُ السَّرِيِّ، حَدَّثَنَا عَبْثَرٌ، عَنْ مُطَرِّفٍ، عَنْ عَامِرٍ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَعْتَقَ جَارِيَتَهُ وَتَزَوَّجَهَا كَانَ لَهُ أَجْرَانِ ‏"‏ ‏.‏\hadithno{2053}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2544) Sahih Muslim (154 After  1427)}\hadithtrans{Abu Dawud reported the Apostle of Allaah(ﷺ) as saying “Anyone who sets his slave girl free and then marries her, will have a double reward.”}}
\hadithdefcmd{abudawud}{2054}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، وَعَبْدِ الْعَزِيزِ بْنِ صُهَيْبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَعْتَقَ صَفِيَّةَ وَجَعَلَ عِتْقَهَا صَدَاقَهَا ‏.‏\hadithno{2054}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (947) Sahih Muslim (1365 After  1427)}\hadithtrans{Anas bin ‘Malik said “The Prophet(ﷺ) manumitted Safiyyah and made her manumission her dower.”}}
\hadithdefcmd{abudawud}{2055}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ سُلَيْمَانَ بْنِ يَسَارٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ يَحْرُمُ مِنَ الرَّضَاعَةِ مَا يَحْرُمُ مِنَ الْوِلاَدَةِ ‏"‏ ‏.‏\hadithno{2055}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Prophet (ﷺ) said: What is unlawful by reason of consanguinity is unlawful by reason of fosterage}}
\hadithdefcmd{abudawud}{2056}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ زَيْنَبَ بِنْتِ أُمِّ سَلَمَةَ، عَنْ أُمِّ سَلَمَةَ، أَنَّ أُمَّ حَبِيبَةَ، قَالَتْ يَا رَسُولَ اللَّهِ هَلْ لَكَ فِي أُخْتِي قَالَ ‏"‏ فَأَفْعَلُ مَاذَا ‏"‏ ‏.‏ قَالَتْ فَتَنْكِحُهَا ‏.‏ قَالَ ‏"‏ أُخْتَكِ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ أَوَتُحِبِّينَ ذَاكَ ‏"‏ ‏.‏ قَالَتْ لَسْتُ بِمُخْلِيَةٍ بِكَ وَأَحَبُّ مَنْ شَرَكَنِي فِي خَيْرٍ أُخْتِي ‏.‏ قَالَ ‏"‏ فَإِنَّهَا لاَ تَحِلُّ لِي ‏"‏ ‏.‏ قَالَتْ فَوَاللَّهِ لَقَدْ أُخْبِرْتُ أَنَّكَ تَخْطُبُ دُرَّةَ - أَوْ ذَرَّةَ شَكَّ زُهَيْرٌ - بِنْتَ أَبِي سَلَمَةَ ‏.‏ قَالَ ‏"‏ بِنْتَ أُمِّ سَلَمَةَ ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ قَالَ ‏"‏ أَمَا وَاللَّهِ لَوْ لَمْ تَكُنْ رَبِيبَتِي فِي حِجْرِي مَا حَلَّتْ لِي إِنَّهَا ابْنَةُ أَخِي مِنَ الرَّضَاعَةِ أَرْضَعَتْنِي وَأَبَاهَا ثُوَيْبَةُ فَلاَ تَعْرِضْنَ عَلَىَّ بَنَاتِكُنَّ وَلاَ أَخَوَاتِكُنَّ ‏"‏ ‏.‏\hadithno{2056}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Umm Salamah reported Umm Habibah said “Are you interested in my sister, Apostle of Allaah(ﷺ)?” He said “What should I do?” She said “You marry her” He said “Your sister?” She said “Yes”. He said “Do you like that?” she said “I am not alone with you of those who share me in this good, my sister is most to my liking. He said “She is not lawful for me.” She said “By Allaah, I was told that you were going to betroth with you Darrah to Durrah , the narrator Zuhair doubted the daughter of Abu Salamah. He said “The daughter of Umm Salamah? She said “Yes”. He said “(She is my step daughter). Even if she had not been my step daughter under my protection, she would not have been lawful for me. She is my foster niece (daughter of my brother by fosterage). Thuwaibah suckled me as well as his father (Abu Salamah). So do not present to me your daughters and your sisters}}
\hadithdefcmd{abudawud}{2057}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ الْعَبْدِيُّ، أَخْبَرَنَا سُفْيَانُ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ دَخَلَ عَلَىَّ أَفْلَحُ بْنُ أَبِي الْقُعَيْسِ فَاسْتَتَرْتُ مِنْهُ ‏.‏ قَالَ تَسْتَتِرِينَ مِنِّي وَأَنَا عَمُّكِ قَالَتْ قُلْتُ مِنْ أَيْنَ قَالَ أَرْضَعَتْكِ امْرَأَةُ أَخِي ‏.‏ قَالَتْ إِنَّمَا أَرْضَعَتْنِي الْمَرْأَةُ وَلَمْ يُرْضِعْنِي الرَّجُلُ ‏.‏ فَدَخَلَ عَلَىَّ رَسُولُ اللَّهِ صلى الله عليه وسلم فَحَدَّثْتُهُ فَقَالَ ‏ "‏ إِنَّهُ عَمُّكِ فَلْيَلِجْ عَلَيْكِ ‏"‏ ‏.‏\hadithno{2057}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (5239) Sahih Muslim (1445)}\hadithtrans{Narrated Aisha, Ummul Mu'minin: Aflah ibn AbulQu'ays entered upon me. I hid myself from him. He said: You are hiding yourself from me while I am your paternal uncle. She said: I said: From where? He said: The wife of my brother suckled you. She said: The woman suckled me and not the man. Thereafter the Messenger of Allah (ﷺ) entered upon me and I told him this matter. He said: He is your paternal uncle; he may enter upon you}}
\hadithdefcmd{abudawud}{2058}{حَدَّثَنَا حَفْصُ بْنُ عُمَرَ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَشْعَثَ بْنِ سُلَيْمٍ، عَنْ أَبِيهِ، عَنْ مَسْرُوقٍ، عَنْ عَائِشَةَ الْمَعْنَى، وَاحِدٌ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم دَخَلَ عَلَيْهَا وَعِنْدَهَا رَجُلٌ قَالَ حَفْصٌ فَشَقَّ ذَلِكَ عَلَيْهِ وَتَغَيَّرَ وَجْهُهُ - ثُمَّ اتَّفَقَا - قَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُ أَخِي مِنَ الرَّضَاعَةِ ‏.‏ فَقَالَ ‏ "‏ انْظُرْنَ مَنْ إِخْوَانُكُنَّ فَإِنَّمَا الرَّضَاعَةُ مِنَ الْمَجَاعَةِ ‏"‏ ‏.‏\hadithno{2058}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2647) Sahih Muslim (1455)}\hadithtrans{A’ishah said the Apostle of Allaah(ﷺ) visited her when a man was with her. The narrator Hafs said “this grieved him and he frowned”. The agreed version then goes, She said “He is my foster brother Apostle of Allaah(ﷺ)”. He said “Consider, who are you brethren, for fosterage is consequent on hunger.”}}
\hadithdefcmd{abudawud}{2059}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ مُطَهِّرٍ، أَنَّ سُلَيْمَانَ بْنَ الْمُغِيرَةِ، حَدَّثَهُمْ عَنْ أَبِي مُوسَى، عَنْ أَبِيهِ، عَنِ ابْنٍ لِعَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ لاَ رِضَاعَ إِلاَّ مَا شَدَّ الْعَظْمَ وَأَنْبَتَ اللَّحْمَ ‏.‏ فَقَالَ أَبُو مُوسَى لاَ تَسْأَلُونَا وَهَذَا الْحَبْرُ فِيكُمْ ‏.‏\hadithno{2059}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{‘Abd Allaah bin Mas’ud said “Fosterage is not valid except by what strengthens love and grows flesh.” Abu Musa said “Do not ask us so long as this learned man is among us”}}
\hadithdefcmd{abudawud}{2060}{حَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ، حَدَّثَنَا وَكِيعٌ، عَنْ سُلَيْمَانَ بْنِ الْمُغِيرَةِ، عَنْ أَبِي مُوسَى الْهِلاَلِيِّ، عَنْ أَبِيهِ، عَنِ ابْنِ مَسْعُودٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ وَقَالَ أَنْشَزَ الْعَظْمَ ‏.‏\hadithno{2060}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been narrated by Ibn Mas’ud through a different chain of narrators and to the same effect from the Prophet (ﷺ). This version has the words anshaz al-‘azma meaning which nourishes bones and makes them sturdy and vigorous}}
\hadithdefcmd{abudawud}{2061}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، حَدَّثَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، حَدَّثَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، عَنْ عَائِشَةَ، زَوْجِ النَّبِيِّ صلى الله عليه وسلم وَأُمِّ سَلَمَةَ أَنَّ أَبَا حُذَيْفَةَ بْنَ عُتْبَةَ بْنِ رَبِيعَةَ بْنِ عَبْدِ شَمْسٍ كَانَ تَبَنَّى سَالِمًا وَأَنْكَحَهُ ابْنَةَ أَخِيهِ هِنْدَ بِنْتَ الْوَلِيدِ بْنِ عُتْبَةَ بْنِ رَبِيعَةَ وَهُوَ مَوْلًى لاِمْرَأَةٍ مِنَ الأَنْصَارِ كَمَا تَبَنَّى رَسُولُ اللَّهِ صلى الله عليه وسلم زَيْدًا وَكَانَ مَنْ تَبَنَّى رَجُلاً فِي الْجَاهِلِيَّةِ دَعَاهُ النَّاسُ إِلَيْهِ وَوُرِّثَ مِيرَاثَهُ حَتَّى أَنْزَلَ اللَّهُ سُبْحَانَهُ وَتَعَالَى فِي ذَلِكَ ‏\{‏ ادْعُوهُمْ لآبَائِهِمْ ‏\}‏ إِلَى قَوْلِهِ ‏\{‏ فَإِخْوَانُكُمْ فِي الدِّينِ وَمَوَالِيكُمْ ‏\}‏ فَرُدُّوا إِلَى آبَائِهِمْ فَمَنْ لَمْ يُعْلَمْ لَهُ أَبٌ كَانَ مَوْلًى وَأَخًا فِي الدِّينِ فَجَاءَتْ سَهْلَةُ بِنْتُ سُهَيْلِ بْنِ عَمْرٍو الْقُرَشِيِّ ثُمَّ الْعَامِرِيِّ - وَهِيَ امْرَأَةُ أَبِي حُذَيْفَةَ - فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّا كُنَّا نَرَى سَالِمًا وَلَدًا وَكَانَ يَأْوِي مَعِي وَمَعَ أَبِي حُذَيْفَةَ فِي بَيْتٍ وَاحِدٍ وَيَرَانِي فُضْلاً وَقَدْ أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ فِيهِمْ مَا قَدْ عَلِمْتَ فَكَيْفَ تَرَى فِيهِ فَقَالَ لَهَا النَّبِيُّ صلى الله عليه وسلم ‏"‏ أَرْضِعِيهِ ‏"‏ ‏.‏ فَأَرْضَعَتْهُ خَمْسَ رَضَعَاتٍ فَكَانَ بِمَنْزِلَةِ وَلَدِهَا مِنَ الرَّضَاعَةِ فَبِذَلِكَ كَانَتْ عَائِشَةُ - رضى الله عنها - تَأْمُرُ بَنَاتِ أَخَوَاتِهَا وَبَنَاتِ إِخْوَتِهَا أَنْ يُرْضِعْنَ مَنْ أَحَبَّتْ عَائِشَةُ أَنْ يَرَاهَا وَيَدْخُلَ عَلَيْهَا وَإِنْ كَانَ كَبِيرًا خَمْسَ رَضَعَاتٍ ثُمَّ يَدْخُلَ عَلَيْهَا وَأَبَتْ أُمُّ سَلَمَةَ وَسَائِرُ أَزْوَاجِ النَّبِيِّ صلى الله عليه وسلم أَنْ يُدْخِلْنَ عَلَيْهِنَّ بِتِلْكَ الرَّضَاعَةِ أَحَدًا مِنَ النَّاسِ حَتَّى يَرْضَعَ فِي الْمَهْدِ وَقُلْنَ لِعَائِشَةَ وَاللَّهِ مَا نَدْرِي لَعَلَّهَا كَانَتْ رُخْصَةً مِنَ النَّبِيِّ صلى الله عليه وسلم لِسَالِمٍ دُونَ النَّاسِ ‏.‏\hadithno{2061}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{A’ishah wife of the Prophet(ﷺ) and Umm Salamah said “Abu Hudaifah bin ‘Utbah bin Rabi’ah bin ‘Abd Shams adopted Salim as his son and married him to his niece Hind, daughter of Al Walid bin ‘Utbah bin Rabi’ah. He (Salim) was the freed slave of a woman from the Ansar (the Helpers) as the Apostle of Allaah(ﷺ) adopted Zaid as his son. In pre Islamic days when anyone adopted a man as his son, the people called him by his name and he was given a share from his inheritance. Allaah, the Exalted, revealed about this matter “Call them by (the name of) their fathers, that is juster in the sight of Allaah. And if ye know not their fathers, then (they are) your brethren in the faith and your clients. They were then called by their names of their fathers. A man, whose father was not known, remained under the protection of someone and considered brother in faith. Sahlah daughter of Suhail bin Amr Al Quraishi then came and said Apostle of Allaah(ﷺ), we used to consider Salim(our) son. He dwelled with me and Abu Hudhaifah in the same house, and he saw me in the short clothes, but Allaah the Exalted, has revealed about them what you know, then what is your opinion about him? The Prophet (ﷺ) said give him your breast feed. She gave him five breast feeds. He then became like her foster son. Hence, A’ishah(may Allaah be pleased with her) used to ask the daughters of her sisters and the daughters of her brethren to give him breast feed five times, whom A’ishah wanted to see and who wanted to visit her. Though he might be of age; he then visited her. But Umm Salamah and all other wives of the Prophet (ﷺ) refused to allow anyone to visit them on the basis of such breast feeding unless one was given breast feed during infancy. They told A’ishah by Allaah we do not know whether that was a special concession granted by the Prophet (ﷺ) to Salim exclusive of the people}}
\hadithdefcmd{abudawud}{2062}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مَسْلَمَةَ الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرِ بْنِ مُحَمَّدِ بْنِ عَمْرِو بْنِ حَزْمٍ، عَنْ عَمْرَةَ بِنْتِ عَبْدِ الرَّحْمَنِ، عَنْ عَائِشَةَ، أَنَّهَا قَالَتْ كَانَ فِيمَا أَنْزَلَ اللَّهُ عَزَّ وَجَلَّ مِنَ الْقُرْآنِ عَشْرُ رَضَعَاتٍ يُحَرِّمْنَ ثُمَّ نُسِخْنَ بِخَمْسٍ مَعْلُومَاتٍ يُحَرِّمْنَ فَتُوُفِّيَ النَّبِيُّ صلى الله عليه وسلم وَهُنَّ مِمَّا يُقْرَأُ مِنَ الْقُرْآنِ ‏.‏\hadithno{2062}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (1452)}\hadithtrans{A’ishah said “In what was sent down in the Qu’ran ten suckling’s made marriage unlawful, but they were abrogated by five known ones and when the Prophet (ﷺ) dies, these words were among what was recited in the Qur’an.”}}
\hadithdefcmd{abudawud}{2063}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا إِسْمَاعِيلُ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، - رضى الله عنها - قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُحَرِّمُ الْمَصَّةُ وَلاَ الْمَصَّتَانِ ‏"‏ ‏.‏\hadithno{2063}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (1450)}\hadithtrans{A’ishah reported “The Apostle of Allaah(ﷺ) as saying One or two sucks does not make marriage unlawful”}}
\hadithdefcmd{abudawud}{2064}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، ح وَحَدَّثَنَا ابْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ حَجَّاجِ بْنِ حَجَّاجٍ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا يُذْهِبُ عَنِّي مَذَمَّةَ الرَّضَاعَةِ قَالَ ‏ "‏ الْغُرَّةُ الْعَبْدُ أَوِ الأَمَةُ ‏"‏ ‏.‏ قَالَ النُّفَيْلِيُّ حَجَّاجُ بْنُ حَجَّاجٍ الأَسْلَمِيُّ وَهَذَا لَفْظُهُ ‏.‏\hadithno{2064}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hajjaj ibn Malik al-Aslami: I asked: Messenger of Allah, what will remove from me the obligation due for fostering a child? He said: A slave or a slave-woman}}
\hadithdefcmd{abudawud}{2065}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنَا دَاوُدُ بْنُ أَبِي هِنْدٍ، عَنْ عَامِرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُنْكَحُ الْمَرْأَةُ عَلَى عَمَّتِهَا وَلاَ الْعَمَّةُ عَلَى بِنْتِ أَخِيهَا وَلاَ الْمَرْأَةُ عَلَى خَالَتِهَا وَلاَ الْخَالَةُ عَلَى بِنْتِ أُخْتِهَا وَلاَ تُنْكَحُ الْكُبْرَى عَلَى الصُّغْرَى وَلاَ الصُّغْرَى عَلَى الْكُبْرَى ‏"‏ ‏.‏\hadithno{2065}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Abu Hurairah reported The Apostle of Allaah(ﷺ) as saying “ A woman should not be married to one who had married her paternal aunt or a paternal aunt to one who had married her brother’s daughter or a woman to one who had married her maternal aunt or maternal aunt to one who had married her sister’s daughter. A woman who is elder (in relation) must not be married to one who had married a woman who is younger (in relation) to her nor a woman who is younger (in relation) must be married to one who has married a woman who is elder (in relation) to her.”}}
\hadithdefcmd{abudawud}{2066}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَنْبَسَةُ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي قَبِيصَةُ بْنُ ذُؤَيْبٍ، أَنَّهُ سَمِعَ أَبَا هُرَيْرَةَ، يَقُولُ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُجْمَعَ بَيْنَ الْمَرْأَةِ وَخَالَتِهَا وَبَيْنَ الْمَرْأَةِ وَعَمَّتِهَا ‏.‏\hadithno{2066}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5110) Sahih Muslim (1408)}\hadithtrans{Abu Hurairah said “The Apostle of Allah (ﷺ) forbade that a woman and her maternal aunt and a woman and her paternal aunt are joined in marriage (to the same man).”}}
\hadithdefcmd{abudawud}{2067}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا خَطَّابُ بْنُ الْقَاسِمِ، عَنْ خُصَيْفٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ كَرِهَ أَنْ يُجْمَعَ بَيْنَ الْعَمَّةِ وَالْخَالَةِ وَبَيْنَ الْخَالَتَيْنِ وَالْعَمَّتَيْنِ ‏.‏\hadithno{2067}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) abominated the combination of paternal and maternal aunts and the combination of two maternal aunts and two paternal aunts in marriage}}
\hadithdefcmd{abudawud}{2068}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا ابْنُ وَهْبٍ، أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، قَالَ أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّهُ سَأَلَ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم عَنْ قَوْلِ اللَّهِ تَعَالَى ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ ‏\}‏ قَالَتْ يَا ابْنَ أُخْتِي هِيَ الْيَتِيمَةُ تَكُونُ فِي حِجْرِ وَلِيِّهَا فَتُشَارِكُهُ فِي مَالِهِ فَيُعْجِبُهُ مَالُهَا وَجَمَالُهَا فَيُرِيدُ أَنْ يَتَزَوَّجَهَا بِغَيْرِ أَنْ يُقْسِطَ فِي صَدَاقِهَا فَيُعْطِيَهَا مِثْلَ مَا يُعْطِيهَا غَيْرُهُ فَنُهُوا أَنْ يَنْكِحُوهُنَّ إِلاَّ أَنْ يُقْسِطُوا لَهُنَّ وَيَبْلُغُوا بِهِنَّ أَعْلَى سُنَّتِهِنَّ مِنَ الصَّدَاقِ وَأُمِرُوا أَنْ يَنْكِحُوا مَا طَابَ لَهُمْ مِنَ النِّسَاءِ سِوَاهُنَّ ‏.‏ قَالَ عُرْوَةُ قَالَتْ عَائِشَةُ ثُمَّ إِنَّ النَّاسَ اسْتَفْتَوْا رَسُولَ اللَّهِ صلى الله عليه وسلم بَعْدَ هَذِهِ الآيَةِ فِيهِنَّ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ وَيَسْتَفْتُونَكَ فِي النِّسَاءِ قُلِ اللَّهُ يُفْتِيكُمْ فِيهِنَّ وَمَا يُتْلَى عَلَيْكُمْ فِي الْكِتَابِ فِي يَتَامَى النِّسَاءِ اللاَّتِي لاَ تُؤْتُونَهُنَّ مَا كُتِبَ لَهُنَّ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ ‏\}‏ قَالَتْ وَالَّذِي ذَكَرَ اللَّهُ أَنَّهُ يُتْلَى عَلَيْهِمْ فِي الْكِتَابِ الآيَةُ الأُولَى الَّتِي قَالَ اللَّهُ سُبْحَانَهُ وَتَعَالَى ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى فَانْكِحُوا مَا طَابَ لَكُمْ مِنَ النِّسَاءِ ‏\}‏ قَالَتْ عَائِشَةُ وَقَوْلُ اللَّهِ عَزَّ وَجَلَّ فِي الآيَةِ الآخِرَةِ ‏\{‏ وَتَرْغَبُونَ أَنْ تَنْكِحُوهُنَّ ‏\}‏ هِيَ رَغْبَةُ أَحَدِكُمْ عَنْ يَتِيمَتِهِ الَّتِي تَكُونُ فِي حِجْرِهِ حِينَ تَكُونُ قَلِيلَةَ الْمَالِ وَالْجَمَالِ فَنُهُوا أَنْ يَنْكِحُوا مَا رَغِبُوا فِي مَالِهَا وَجَمَالِهَا مِنْ يَتَامَى النِّسَاءِ إِلاَّ بِالْقِسْطِ مِنْ أَجْلِ رَغْبَتِهِمْ عَنْهُنَّ ‏.‏ قَالَ يُونُسُ وَقَالَ رَبِيعَةُ فِي قَوْلِ اللَّهِ عَزَّ وَجَلَّ ‏\{‏ وَإِنْ خِفْتُمْ أَنْ لاَ تُقْسِطُوا فِي الْيَتَامَى ‏\}‏ قَالَ يَقُولُ اتْرُكُوهُنَّ إِنْ خِفْتُمْ فَقَدْ أَحْلَلْتُ لَكُمْ أَرْبَعًا ‏.‏\hadithno{2068}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5064) Sahih Muslim (3018)}\hadithtrans{Ibn Shihab said “’Urwah bin Al Zubair asked A’ishah , wife of the Prophet(ﷺ) about the Qur’anic verse “And if ye fear that ye will not deal fairly by the orphans, marry of the women, who seem good to you.” She said “O my nephew, this means the female orphan who is under the protection of her guardian and she holds a share in his property and her property and beauty attracts him; so her guardian intends to marry her without doing justice to her in respect of her dower and he gives her the same amount of dower as others give her. They (i.e., the guardians) were prohibited to marry them except that they do justice to them and pay them their maximum customary dower and they were asked to marry women other than them (i.e., the orphans) who seem good to them. ‘Urwah reported that A’ishah said “The people then consulted the Apostle of Allaah(ﷺ) about women after revelation of this verse. Thereupon Allaah the Exalted sent down the verse “They consult thee concerning women. Say Allaah giveth you decree concerning them and the scripture which hath been recited unto you(giveth decree) concerning female orphans unto whom you give not that which is ordained for them though you desire to marry them. “ She said “The mention made by Allaah about the Scripture recited to them refers to the former verse in which Allaah has said “And if ye fear that ye will not deal fairly by the orphans, marry of the women, who seem good to you.” A’ishah said “The pronouncement of Allaah , the Exalted in the latter verse “though you desire to marry them” means the disinterest of one of you in marrying a female orphan who was under his protection, but she said little property and beauty. So they were prohibited to marry them for their interest in the property and beauty of the female orphans due to their disinterest in themselves except that they do justice )to them). The narrator Yunus said “Rabi’ah said explain the Qur’anic verse “And if ye fear that ye will not deal fairly by the orphans” means “Leave them if you fear (that you will not do justice to them), for I have made four women lawful for you.”}}
\hadithdefcmd{abudawud}{2069}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ حَنْبَلٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ بْنِ سَعْدٍ، حَدَّثَنِي أَبِي، عَنِ الْوَلِيدِ بْنِ كَثِيرٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرِو بْنِ حَلْحَلَةَ الدُّؤَلِيُّ، أَنَّ ابْنَ شِهَابٍ، حَدَّثَهُ أَنَّ عَلِيَّ بْنَ الْحُسَيْنِ حَدَّثَهُ أَنَّهُمْ، حِينَ قَدِمُوا الْمَدِينَةَ مِنْ عِنْدِ يَزِيدَ بْنِ مُعَاوِيَةَ مَقْتَلَ الْحُسَيْنِ بْنِ عَلِيٍّ - رضى الله عنهما - لَقِيَهُ الْمِسْوَرُ بْنُ مَخْرَمَةَ فَقَالَ لَهُ هَلْ لَكَ إِلَىَّ مِنْ حَاجَةٍ تَأْمُرُنِي بِهَا قَالَ فَقُلْتُ لَهُ لاَ ‏.‏ قَالَ هَلْ أَنْتَ مُعْطِيَّ سَيْفَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَإِنِّي أَخَافُ أَنْ يَغْلِبَكَ الْقَوْمُ عَلَيْهِ وَايْمُ اللَّهِ لَئِنْ أَعْطَيْتَنِيهِ لاَ يُخْلَصُ إِلَيْهِ أَبَدًا حَتَّى يَبْلُغَ إِلَى نَفْسِي إِنَّ عَلِيَّ بْنَ أَبِي طَالِبٍ - رضى الله عنه - خَطَبَ بِنْتَ أَبِي جَهْلٍ عَلَى فَاطِمَةَ - رضى الله عنها - فَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهُوَ يَخْطُبُ النَّاسَ فِي ذَلِكَ عَلَى مِنْبَرِهِ هَذَا وَأَنَا يَوْمَئِذٍ مُحْتَلِمٌ فَقَالَ ‏"‏ إِنَّ فَاطِمَةَ مِنِّي وَأَنَا أَتَخَوَّفُ أَنْ تُفْتَنَ فِي دِينِهَا ‏"‏ ‏.‏ قَالَ ثُمَّ ذَكَرَ صِهْرًا لَهُ مِنْ بَنِي عَبْدِ شَمْسٍ فَأَثْنَى عَلَيْهِ فِي مُصَاهَرَتِهِ إِيَّاهُ فَأَحْسَنَ قَالَ ‏"‏ حَدَّثَنِي فَصَدَقَنِي وَوَعَدَنِي فَوَفَّى لِي وَإِنِّي لَسْتُ أُحَرِّمُ حَلاَلاً وَلاَ أُحِلُّ حَرَامًا وَلَكِنْ وَاللَّهِ لاَ تَجْتَمِعُ بِنْتُ رَسُولِ اللَّهِ وَبِنْتُ عَدُوِّ اللَّهِ مَكَانًا وَاحِدًا أَبَدًا ‏"‏ ‏.‏\hadithno{2069}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3110) Sahih Muslim (2449)}\hadithtrans{‘Ali bin al-Hussain said that when they returned to Madeenah from Yazid bin Mu’awiyah the place of massacre of Al Hussain bin Ali(may Allaah be pleased with him) Al Miswar bin Makhramah met them and said “tell me if you have any need for me. I said to him “No”. He then said Will you not give me the sword of the Apostle of Allaah(ﷺ)? I fear the people may not take it from you by force. (He said) By Allaah if you give it to me no one can take it from me so long as I am alive. Ali bin Abi Talib (may Allaah be pleased with him) asked for the hand of Abu Jahl’s daughter in marriage after the marriage with Fathima. I heard the Apostle of Allaah(ﷺ) say while he was addressing the people about this matter on the pulpit and I was mature in those days. Fathima is from me and I am not afraid that she will be tried in respect of her religion. He then mentioned his other son-in-law who belonged to Banu ‘Abd Shams. He admired him immensely for his relationship with him and extolled him well. He said “He talked to me and talked truly and he made promise with me and fulfilled it. I do not make lawful what Is unlawful and unlawful what is lawful. But, by Allaah the daughter of the Apostle of Allaah(ﷺ) and the daughter of the enemy of Allaah can never be combined together}}
\hadithdefcmd{abudawud}{2070}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنِي عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أَيُّوبَ، عَنِ ابْنِ أَبِي مُلَيْكَةَ، بِهَذَا الْخَبَرِ قَالَ فَسَكَتَ عَلِيٌّ عَنْ ذَلِكَ النِّكَاحِ\hadithno{2070}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5230) Sahih Muslim (2449)}\hadithtrans{The aforesaid tradition has also been transmitted by Ibn Abi Mulaikah. He said “’Ali (Allaah be pleased with him) then kept silence about the marriage (i.e., marrying Abi Jahl’s daughter)}}
\hadithdefcmd{abudawud}{2071}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، وَقُتَيْبَةُ بْنُ سَعِيدٍ، - الْمَعْنَى - قَالَ أَحْمَدُ حَدَّثَنَا اللَّيْثُ، حَدَّثَنِي عَبْدُ اللَّهِ بْنُ عُبَيْدِ اللَّهِ بْنِ أَبِي مُلَيْكَةَ الْقُرَشِيُّ التَّيْمِيُّ، أَنَّ الْمِسْوَرَ بْنَ مَخْرَمَةَ، حَدَّثَهُ أَنَّهُ، سَمِعَ رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى الْمِنْبَرِ يَقُولُ ‏ "‏ إِنَّ بَنِي هِشَامِ بْنِ الْمُغِيرَةِ اسْتَأْذَنُونِي أَنْ يُنْكِحُوا ابْنَتَهُمْ مِنْ عَلِيِّ بْنِ أَبِي طَالِبٍ فَلاَ آذَنُ ثُمَّ لاَ آذَنُ ثُمَّ لاَ آذَنُ إِلاَّ أَنْ يُرِيدَ ابْنُ أَبِي طَالِبٍ أَنْ يُطَلِّقَ ابْنَتِي وَيَنْكِحَ ابْنَتَهُمْ فَإِنَّمَا ابْنَتِي بَضْعَةٌ مِنِّي يُرِيبُنِي مَا أَرَابَهَا وَيُؤْذِينِي مَا آذَاهَا ‏"‏ ‏.‏ وَالإِخْبَارُ فِي حَدِيثِ أَحْمَدَ ‏.‏\hadithno{2071}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (5230) Sahih Muslim (2449)}\hadithtrans{Al Miswar bin Makramah said that he heard the Apostle of Allaah(ﷺ) say on the pulpit Banu Hashim bin Al Mughirah sought permission from me to marry their daughter to ‘Ali bin Abi Talib. But I do not permit, again, I do not permit, again, I do not permit except that Ibn Abi Talib divorces my daughter and marries their daughter. My daughter is my part, what makes her uneasy makes me uneasy and what troubles her troubles me. The full information rests with the tradition narrated by Ahmad}}
\hadithdefcmd{abudawud}{2072}{حَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا عَبْدُ الْوَارِثِ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، عَنِ الزُّهْرِيِّ، قَالَ كُنَّا عِنْدَ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ فَتَذَاكَرْنَا مُتْعَةَ النِّسَاءِ فَقَالَ لَهُ رَجُلٌ يُقَالُ لَهُ رَبِيعُ بْنُ سَبْرَةَ أَشْهَدُ عَلَى أَبِي أَنَّهُ حَدَّثَ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنْهَا فِي حَجَّةِ الْوَدَاعِ ‏.‏\hadithno{2072}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Daif}\hadithtrans{Al Zuhri said “we were with ‘Umar bin ‘Abd Al Aziz, there we discussed temporary marriage. A man called Rabi bin Saburah said “I bear witness that my father told me that the Apostle of Allaah(ﷺ) had prohibited it at the Farewell Pilgrimage.”}}
\hadithdefcmd{abudawud}{2073}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ رَبِيعِ بْنِ سَبْرَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَرَّمَ مُتْعَةَ النِّسَاءِ ‏.‏\hadithno{2073}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1406)}\hadithtrans{Rabi' b. Saburah reported on the authority of his father:The Messenger of Allah (ﷺ) prohibited temporary marriage with women}}
\hadithdefcmd{abudawud}{2074}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، ح وَحَدَّثَنَا مُسَدَّدُ بْنُ مُسَرْهَدٍ، حَدَّثَنَا يَحْيَى، عَنْ عُبَيْدِ اللَّهِ، كِلاَهُمَا عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى عَنِ الشِّغَارِ ‏.‏ زَادَ مُسَدَّدٌ فِي حَدِيثِهِ قُلْتُ لِنَافِعٍ مَا الشِّغَارُ قَالَ يَنْكِحُ ابْنَةَ الرَّجُلِ وَيُنْكِحُهُ ابْنَتَهُ بِغَيْرِ صَدَاقٍ وَيَنْكِحُ أُخْتَ الرَّجُلِ وَيُنْكِحُهُ أُخْتَهُ بِغَيْرِ صَدَاقٍ ‏.‏\hadithno{2074}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (5112) Sahih Muslim (1415)}\hadithtrans{Ibn ‘Umar said “The Apostle of Allaah(ﷺ) prohibited shighar marriage. Musaddad added in his version “I said to ‘Nafi “What is shighar?” (It means that) a man marries the daughter of another man and gives his own daughter to him in marriage without fixing dower; and a man marries the sister of another man and gives him his sister in marriage without fixing dower}}
\hadithdefcmd{abudawud}{2075}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا يَعْقُوبُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبِي، عَنِ ابْنِ إِسْحَاقَ، حَدَّثَنِي عَبْدُ الرَّحْمَنِ بْنُ هُرْمُزَ الأَعْرَجُ، أَنَّ الْعَبَّاسَ بْنَ عَبْدِ اللَّهِ بْنِ الْعَبَّاسِ، أَنْكَحَ عَبْدَ الرَّحْمَنِ بْنَ الْحَكَمِ ابْنَتَهُ وَأَنْكَحَهُ عَبْدُ الرَّحْمَنِ ابْنَتَهُ وَكَانَا جَعَلاَ صَدَاقًا فَكَتَبَ مُعَاوِيَةُ إِلَى مَرْوَانَ يَأْمُرُهُ بِالتَّفْرِيقِ بَيْنَهُمَا وَقَالَ فِي كِتَابِهِ هَذَا الشِّغَارُ الَّذِي نَهَى عَنْهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2075}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Abdur Rahman ibn Hurmuz al-A'raj said:Al-Abbas ibn Abdullah ibn al-Abbas married his daughter to Abdur Rahman ibn al-Hakam, and AbdurRahman married his daughter to him. And they made this (exchange) their dower. Mu'awiyah wrote to Marwan commanding him to separate them. He wrote in his letter: This is the shighar which the Messenger of Allah (ﷺ) has forbidden}}
\hadithdefcmd{abudawud}{2076}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا زُهَيْرٌ، حَدَّثَنِي إِسْمَاعِيلُ، عَنْ عَامِرٍ، عَنِ الْحَارِثِ، عَنْ عَلِيٍّ، رضى الله عنه - قَالَ إِسْمَاعِيلُ وَأُرَاهُ قَدْ رَفَعَهُ إِلَى النَّبِيِّ صلى الله عليه وسلم - أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لَعَنَ اللَّهُ الْمُحَلِّلَ وَالْمُحَلَّلَ لَهُ ‏"‏ ‏.‏\hadithno{2076}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ali ibn AbuTalib: (The narrator Isma'il said: I think ash-Sha'bi attributed this tradition to the Prophet) The Prophet (ﷺ) said: Curse be upon the one who marries a divorced woman with the intention of making her lawful for her former husband and upon the one for whom she is made lawful}}
\hadithdefcmd{abudawud}{2077}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، عَنْ خَالِدٍ، عَنْ حُصَيْنٍ، عَنْ عَامِرٍ، عَنِ الْحَارِثِ الأَعْوَرِ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم قَالَ فَرَأَيْنَا أَنَّهُ عَلِيٌّ - عَلَيْهِ السَّلاَمُ - عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏\hadithno{2077}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been transmitted by ‘Ali through a different chain of narrators from the Prophet (ﷺ) to the same effect}}
\hadithdefcmd{abudawud}{2078}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، - وَهَذَا لَفْظُ إِسْنَادِهِ - وَكِلاَهُمَا عَنْ وَكِيعٍ، حَدَّثَنَا الْحَسَنُ بْنُ صَالِحٍ، عَنْ عَبْدِ اللَّهِ بْنِ مُحَمَّدِ بْنِ عَقِيلٍ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا عَبْدٍ تَزَوَّجَ بِغَيْرِ إِذْنِ مَوَالِيهِ فَهُوَ عَاهِرٌ ‏"‏ ‏.‏\hadithno{2078}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If any slave marries without the permission of his masters, he is a fornicator}}
\hadithdefcmd{abudawud}{2079}{حَدَّثَنَا عُقْبَةُ بْنُ مُكْرَمٍ، حَدَّثَنَا أَبُو قُتَيْبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا نَكَحَ الْعَبْدُ بِغَيْرِ إِذْنِ مَوْلاَهُ فَنِكَاحُهُ بَاطِلٌ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هَذَا الْحَدِيثُ ضَعِيفٌ وَهُوَ مَوْقُوفٌ وَهُوَ قَوْلُ ابْنِ عُمَرَ رضى الله عنهما ‏.‏\hadithno{2079}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Umar reported the Prophet (ﷺ) as saying “If a slave marries without the permission of his master, his marriage is null and void. Abu Dawud said “This tradition is weak. This is mauquf(does not go back to the Prophet). This is the statement of the Ibn ‘Umar himself}}
\hadithdefcmd{abudawud}{2080}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَخْطُبُ الرَّجُلُ عَلَى خِطْبَةِ أَخِيهِ ‏"‏ ‏.‏\hadithno{2080}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (2140) Sahih Muslim (1413)}\hadithtrans{Abu Hurairah reported the Apostle of Allaah(ﷺ) as saying “ A man should not seek the hand of a woman in marriage when his brother has already sought her hand.”}}
\hadithdefcmd{abudawud}{2081}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَخْطُبُ أَحَدُكُمْ عَلَى خِطْبَةِ أَخِيهِ وَلاَ يَبِيعُ عَلَى بَيْعِ أَخِيهِ إِلاَّ بِإِذْنِهِ ‏"‏ ‏.‏\hadithno{2081}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5142) Sahih Muslim (1412)}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: One of you must not ask a woman in marriage when his brother has done so already, and one of you must not sell (his own goods) when his brother has already sold (his goods) except with his permission}}
\hadithdefcmd{abudawud}{2082}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ زِيَادٍ، حَدَّثَنَا مُحَمَّدُ بْنُ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ حُصَيْنٍ، عَنْ وَاقِدِ بْنِ عَبْدِ الرَّحْمَنِ، - يَعْنِي ابْنَ سَعْدِ بْنِ مُعَاذٍ - عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِذَا خَطَبَ أَحَدُكُمُ الْمَرْأَةَ فَإِنِ اسْتَطَاعَ أَنْ يَنْظُرَ إِلَى مَا يَدْعُوهُ إِلَى نِكَاحِهَا فَلْيَفْعَلْ ‏"‏ ‏.‏ قَالَ فَخَطَبْتُ جَارِيَةً فَكُنْتُ أَتَخَبَّأُ لَهَا حَتَّى رَأَيْتُ مِنْهَا مَا دَعَانِي إِلَى نِكَاحِهَا وَتَزَوُّجِهَا فَتَزَوَّجْتُهَا ‏.‏\hadithno{2082}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: When one of you asked a woman in marriage, if he is able to look at what will induce him to marry her, he should do so. He (Jabir) said: I asked a girl in marriage, I used to look at her secretly, until I looked at what induced me to marry her. I, therefore, married her}}
\hadithdefcmd{abudawud}{2083}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَيُّمَا امْرَأَةٍ نَكَحَتْ بِغَيْرِ إِذْنِ مَوَالِيهَا فَنِكَاحُهَا بَاطِلٌ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏"‏ فَإِنْ دَخَلَ بِهَا فَالْمَهْرُ لَهَا بِمَا أَصَابَ مِنْهَا فَإِنْ تَشَاجَرُوا فَالسُّلْطَانُ وَلِيُّ مَنْ لاَ وَلِيَّ لَهُ ‏"‏ ‏.‏\hadithno{2083}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) said: The marriage of a woman who marries without the consent of her guardians is void. (He said these words) three times. If there is cohabitation, she gets her dower for the intercourse her husband has had. If there is a dispute, the sultan (man in authority) is the guardian of one who has none}}
\hadithdefcmd{abudawud}{2084}{حَدَّثَنِي الْقَعْنَبِيُّ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ جَعْفَرٍ، - يَعْنِي ابْنَ رَبِيعَةَ - عَنِ ابْنِ شِهَابٍ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِمَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ جَعْفَرٌ لَمْ يَسْمَعْ مِنَ الزُّهْرِيِّ كَتَبَ إِلَيْهِ ‏.‏\hadithno{2084}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{This tradition has also been transmitted by A’ishah through a different chain of narrators from the Prophet (ﷺ) to the same effect. Abu Dawud said “Ja’far did not hear any tradition from Al Zuhri. Al Zuhri gave him his writing.”}}
\hadithdefcmd{abudawud}{2085}{حَدَّثَنَا مُحَمَّدُ بْنُ قُدَامَةَ بْنِ أَعْيَنَ، حَدَّثَنَا أَبُو عُبَيْدَةَ الْحَدَّادُ، عَنْ يُونُسَ، وَإِسْرَائِيلَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي بُرْدَةَ، عَنْ أَبِي مُوسَى، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ نِكَاحَ إِلاَّ بِوَلِيٍّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ هُوَ يُونُسُ عَنْ أَبِي بُرْدَةَ وَإِسْرَائِيلُ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي بُرْدَةَ ‏.‏\hadithno{2085}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Musa: The Prophet (ﷺ) said: There is no marriage without the permission of a guardian. Abu Dawud said: The narrator Yunus also transmitted on the authority of Abu Burdah, and Isra'il narrated from Abu Ishaq on the authority of Abu Burdah}}
\hadithdefcmd{abudawud}{2086}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنْ مَعْمَرٍ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أُمِّ حَبِيبَةَ، أَنَّهَا كَانَتْ عِنْدَ ابْنِ جَحْشٍ فَهَلَكَ عَنْهَا - وَكَانَ فِيمَنْ هَاجَرَ إِلَى أَرْضِ الْحَبَشَةِ - فَزَوَّجَهَا النَّجَاشِيُّ رَسُولَ اللَّهِ صلى الله عليه وسلم وَهِيَ عِنْدَهُمْ ‏.‏\hadithno{2086}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Ibn Az-Zubayr reported on the authority of Umm Habibah that she was the wife of Ibn Jahsh, but he died, He was among those who migrated to Abyssinia. Negus then married her to the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{2087}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنِي أَبُو عَامِرٍ، حَدَّثَنَا عَبَّادُ بْنُ رَاشِدٍ، عَنِ الْحَسَنِ، حَدَّثَنِي مَعْقِلُ بْنُ يَسَارٍ، قَالَ كَانَتْ لِي أُخْتٌ تُخْطَبُ إِلَىَّ فَأَتَانِي ابْنُ عَمٍّ لِي فَأَنْكَحْتُهَا إِيَّاهُ ثُمَّ طَلَّقَهَا طَلاَقًا لَهُ رَجْعَةٌ ثُمَّ تَرَكَهَا حَتَّى انْقَضَتْ عِدَّتُهَا فَلَمَّا خُطِبَتْ إِلَىَّ أَتَانِي يَخْطُبُهَا فَقُلْتُ لاَ وَاللَّهِ لاَ أُنْكِحُهَا أَبَدًا ‏.‏ قَالَ فَفِيَّ نَزَلَتْ هَذِهِ الآيَةُ ‏\{‏ وَإِذَا طَلَّقْتُمُ النِّسَاءَ فَبَلَغْنَ أَجَلَهُنَّ فَلاَ تَعْضُلُوهُنَّ أَنْ يَنْكِحْنَ أَزْوَاجَهُنَّ ‏\}‏ الآيَةَ ‏.‏ قَالَ فَكَفَّرْتُ عَنْ يَمِينِي فَأَنْكَحْتُهَا إِيَّاهُ ‏.‏\hadithno{2087}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari (4529)}\hadithtrans{Ma’qil bin Yasar said:I had a sister and I was asked to give her in marriage. My cousin came to me and I married her to him. He then divorced her one revocable divorce. He abandoned her till her waiting period passed. When I was asked to give her in marriage, he again came to me and asked her in marriage. Thereupon I said to him “No, by Allah, I will never marry her to you. Then the following verse was revealed about my case: “And when ye have divorced women and they reach their term, place not difficulties in the way of their marrying their husbands.” So I expiated for my oath, and married her off to him}}
\hadithdefcmd{abudawud}{2088}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا هَمَّامٌ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - الْمَعْنَى - عَنْ قَتَادَةَ، عَنِ الْحَسَنِ، عَنْ سَمُرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ أَيُّمَا امْرَأَةٍ زَوَّجَهَا وَلِيَّانِ فَهِيَ لِلأَوَّلِ مِنْهُمَا وَأَيُّمَا رَجُلٍ بَاعَ بَيْعًا مِنْ رَجُلَيْنِ فَهُوَ لِلأَوَّلِ مِنْهُمَا ‏"‏ ‏.‏\hadithno{2088}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Samurah: The Prophet (ﷺ) said: Any woman who is married by two guardians (to two different men) belongs to the first woman who is married by two guardians (to two different men) belongs to the first of them and anything sold by a man to two persons belongs to the first of them}}
\hadithdefcmd{abudawud}{2089}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا أَسْبَاطُ بْنُ مُحَمَّدٍ، حَدَّثَنَا الشَّيْبَانِيُّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، - قَالَ الشَّيْبَانِيُّ وَذَكَرَهُ عَطَاءٌ أَبُو الْحَسَنِ السُّوَائِيُّ وَلاَ أَظُنُّهُ إِلاَّ عَنِ ابْنِ عَبَّاسٍ، - فِي هَذِهِ الآيَةِ ‏\{‏ لاَ يَحِلُّ لَكُمْ أَنْ تَرِثُوا النِّسَاءَ كَرْهًا وَلاَ تَعْضُلُوهُنَّ ‏\}‏ قَالَ كَانَ الرَّجُلُ إِذَا مَاتَ كَانَ أَوْلِيَاؤُهُ أَحَقَّ بِامْرَأَتِهِ مِنْ وَلِيِّ نَفْسِهَا إِنْ شَاءَ بَعْضُهُمْ زَوَّجَهَا أَوْ زَوَّجُوهَا وَإِنْ شَاءُوا لَمْ يُزَوِّجُوهَا فَنَزَلَتْ هَذِهِ الآيَةُ فِي ذَلِكَ ‏.‏\hadithno{2089}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4579، 6948)}\hadithtrans{Narrated Abdullah ibn Abbas: About the Qur'anic verse: "It is not lawful for you forcibly to inherit the woman (of your deceased kinsmen), nor (that) ye should put constraint upon them. When a man died, his relatives had more right to his wife then her own guardian. If any one of them wanted to marry her, he did so; or they married her (to some other person), and if they did not want to marry her, they did so. So this verse was revealed about the matter}}
\hadithdefcmd{abudawud}{2090}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدِ بْنِ ثَابِتٍ الْمَرْوَزِيُّ، حَدَّثَنِي عَلِيُّ بْنُ حُسَيْنِ بْنِ وَاقِدٍ، عَنْ أَبِيهِ، عَنْ يَزِيدَ النَّحْوِيِّ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ ‏\{‏ لاَ يَحِلُّ لَكُمْ أَنْ تَرِثُوا النِّسَاءَ كَرْهًا وَلاَ تَعْضُلُوهُنَّ لِتَذْهَبُوا بِبَعْضِ مَا آتَيْتُمُوهُنَّ إِلاَّ أَنْ يَأْتِينَ بِفَاحِشَةٍ مُبَيِّنَةٍ ‏\}‏ وَذَلِكَ أَنَّ الرَّجُلَ كَانَ يَرِثُ امْرَأَةَ ذِي قَرَابَتِهِ فَيَعْضُلُهَا حَتَّى تَمُوتَ أَوْ تَرُدَّ إِلَيْهِ صَدَاقَهَا فَأَحْكَمَ اللَّهُ عَنْ ذَلِكَ وَنَهَى عَنْ ذَلِكَ ‏.‏\hadithno{2090}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Ibn ‘Abbas explained the Qur’anic verse It is not lawful for you forcibly to inherit the woman (of your deceased kinsmen) nor (that) ye should put constraint upon them that ye may take away a part of that which ye have given them, unless they be guilty of flagrant lewdness and said “This means that a man used to inherit a relative woman. He prevented her from marriage till she died or returned her dower to her. Hence, Allaah prohibited that practice}}
\hadithdefcmd{abudawud}{2091}{حَدَّثَنَا أَحْمَدُ بْنُ شَبُّويَةَ الْمَرْوَزِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ، عَنْ عِيسَى بْنِ عُبَيْدٍ، عَنْ عُبَيْدِ اللَّهِ، مَوْلَى عُمَرَ عَنِ الضَّحَّاكِ، بِمَعْنَاهُ قَالَ فَوَعَظَ اللَّهُ ذَلِكَ ‏.‏\hadithno{2091}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Lighairihi; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{The aforesaid tradition has also been transmitted by Al Dahhak to the same effect through a different chain of narrators. This version has Allaah prohibited that (practice)}}
\hadithdefcmd{abudawud}{2092}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لاَ تُنْكَحُ الثَّيِّبُ حَتَّى تُسْتَأْمَرَ وَلاَ الْبِكْرُ إِلاَّ بِإِذْنِهَا ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَمَا إِذْنُهَا قَالَ ‏"‏ أَنْ تَسْكُتَ ‏"‏ ‏.‏\hadithno{2092}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (6970، 5136) Sahih Muslim (1419)}\hadithtrans{Abu Hurairah reported the Prophet(ﷺ) as saying “ A woman who has been previously married should not be married until her permission is asked nor should a virgin be married without her permission. “They (the people) asked “What is her permission, Apostle of Allaah(ﷺ)? He replied “it is by her keeping silence.”}}
\hadithdefcmd{abudawud}{2093}{حَدَّثَنَا أَبُو كَامِلٍ، حَدَّثَنَا يَزِيدُ يَعْنِي ابْنَ زُرَيْعٍ، ح وَحَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، - الْمَعْنَى - حَدَّثَنِي مُحَمَّدُ بْنُ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ تُسْتَأْمَرُ الْيَتِيمَةُ فِي نَفْسِهَا فَإِنْ سَكَتَتْ فَهُوَ إِذْنُهَا وَإِنْ أَبَتْ فَلاَ جَوَازَ عَلَيْهَا ‏"‏ ‏.‏ وَالإِخْبَارُ فِي حَدِيثِ يَزِيدَ ‏.‏ قَالَ أَبُو دَاوُدَ وَكَذَلِكَ رَوَاهُ أَبُو خَالِدٍ سُلَيْمَانُ بْنُ حَيَّانَ وَمُعَاذٌ عَنْ مُحَمَّدِ بْنِ عَمْرٍو ‏.‏\hadithno{2093}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: The Prophet (ﷺ) said: An orphan virgin girl should be consulted about herself; if she says nothing that indicates her permission, but if she refuses, the authority of the guardian cannot be exercised against her will. The full information rest with the tradition narrated by Yazid. Abu Dawud said: This tradition has also been transmitted in a similar way by Abu Khalid Sulaiman b. Hayyan and Mu'adh b. Mu'adh on the authority of Muhammad b. 'Amr}}
\hadithdefcmd{abudawud}{2094}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، حَدَّثَنَا ابْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، بِهَذَا الْحَدِيثِ بِإِسْنَادِهِ زَادَ فِيهِ قَالَ ‏"‏ فَإِنْ بَكَتْ أَوْ سَكَتَتْ ‏"‏ ‏.‏ زَادَ ‏"‏ بَكَتْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ وَلَيْسَ ‏"‏ بَكَتْ ‏"‏ ‏.‏ بِمَحْفُوظٍ وَهُوَ وَهَمٌ فِي الْحَدِيثِ الْوَهَمُ مِنِ ابْنِ إِدْرِيسَ أَوْ مِنْ مُحَمَّدِ بْنِ الْعَلاَءِ ‏.‏ قَالَ أَبُو دَاوُدَ وَرَوَاهُ أَبُو عَمْرٍو ذَكْوَانُ عَنْ عَائِشَةَ قَالَتْ يَا رَسُولَ اللَّهِ إِنَّ الْبِكْرَ تَسْتَحِي أَنْ تَتَكَلَّمَ ‏.‏ قَالَ ‏"‏ سُكَاتُهَا إِقْرَارُهَا ‏"‏ ‏.‏\hadithno{2094}\hadithgrade{Al-Albani: Shadh; Muhammad Muhyi Al-Din Abdul Hamid: Shadh; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{The aforesaid tradition has also been transmitted through a different chain of narrators by Muhammad bin ‘Amr. This version adds “If she weeps or keeps silence”. The narrator added the word “weeps”. Abu Dawud said:The word "weeps" is not guarded. This is a misunderstanding of the tradition on the part of the narrator Ibn Idris or Muhammad b. al-'Ata. Abu Dawud said: This tradition has also been narrated by Abu 'Amr Dhakwan on the authority of 'Aishah who said: A virgin is ashamed of speaking, Messenger of Allah. He said: Her silence is her acceptance}}
\hadithdefcmd{abudawud}{2095}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُعَاوِيَةُ بْنُ هِشَامٍ، عَنْ سُفْيَانَ، عَنْ إِسْمَاعِيلَ بْنِ أُمَيَّةَ، حَدَّثَنِي الثِّقَةُ، عَنِ ابْنِ عُمَرَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ آمِرُوا النِّسَاءَ فِي بَنَاتِهِنَّ ‏"‏ ‏.‏\hadithno{2095}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Umar: The Prophet (ﷺ) said: Consult women about (the marriage of) their daughters}}
\hadithdefcmd{abudawud}{2096}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ جَارِيَةً، بِكْرًا أَتَتِ النَّبِيَّ صلى الله عليه وسلم فَذَكَرَتْ أَنَّ أَبَاهَا زَوَّجَهَا وَهِيَ كَارِهَةٌ فَخَيَّرَهَا النَّبِيُّ صلى الله عليه وسلم ‏.‏\hadithno{2096}\hadithgrade{Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah ibn Abbas: A virgin came to the Prophet (ﷺ) and mentioned that her father had married her against her will, so the Prophet (ﷺ) allowed her to exercise her choice}}
\hadithdefcmd{abudawud}{2097}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذَا الْحَدِيثِ ‏.‏ قَالَ أَبُو دَاوُدَ لَمْ يَذْكُرِ ابْنَ عَبَّاسٍ وَكَذَلِكَ رَوَاهُ النَّاسُ مُرْسَلاً مَعْرُوفٌ ‏.‏\hadithno{2097}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{The above tradition has been transmitted by ‘Ikrimah from the Prophet (ﷺ). Abu Dawud said “He (Muhammad bin ‘Ubaid) did not mention the name of Ibn ‘Abbas in the chain of this tradition. The people have also narrated it mursal (without the mention of the name of Ibn ‘Abbas) in a similar way. Its transmission in the mursal form is well known}}
\hadithdefcmd{abudawud}{2098}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، وَعَبْدُ اللَّهِ بْنُ مَسْلَمَةَ، قَالاَ أَخْبَرَنَا مَالِكٌ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، عَنْ نَافِعِ بْنِ جُبَيْرٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الأَيِّمُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ تُسْتَأْذَنُ فِي نَفْسِهَا وَإِذْنُهَا صُمَاتُهَا ‏"‏ ‏.‏ وَهَذَا لَفْظُ الْقَعْنَبِيِّ ‏.‏\hadithno{2098}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1421)}\hadithtrans{Ibn ‘Abbas reported the Apostle of Allaah(ﷺ) as saying “A woman without a husband has more right to her person than her guardian and a virgin’s permission must be asked, her permission being her silence. These are the words of Al Qa’nabi}}
\hadithdefcmd{abudawud}{2099}{حَدَّثَنَا أَحْمَدُ بْنُ حَنْبَلٍ، حَدَّثَنَا سُفْيَانُ، عَنْ زِيَادِ بْنِ سَعْدٍ، عَنْ عَبْدِ اللَّهِ بْنِ الْفَضْلِ، بِإِسْنَادِهِ وَمَعْنَاهُ قَالَ ‏"‏ الثَّيِّبُ أَحَقُّ بِنَفْسِهَا مِنْ وَلِيِّهَا وَالْبِكْرُ يَسْتَأْمِرُهَا أَبُوهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ أَبُوهَا ‏"‏ ‏.‏ لَيْسَ بِمَحْفُوظٍ ‏.‏\hadithno{2099}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1421)}\hadithtrans{The above tradition has been transmitted by ‘Abd Allaah bin Al Fadl through his chain of narrators and with different meaning. The version goes “A woman without a husband has more right to her person than her guardian and the father of a virgin should ask her permission about herself.” Abu Dawud said “ The word “her father” is not guarded}}
\hadithdefcmd{abudawud}{2100}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنْ صَالِحِ بْنِ كَيْسَانَ، عَنْ نَافِعِ بْنِ جُبَيْرِ بْنِ مُطْعِمٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ لِلْوَلِيِّ مَعَ الثَّيِّبِ أَمْرٌ وَالْيَتِيمَةُ تُسْتَأْمَرُ وَصَمْتُهَا إِقْرَارُهَا ‏"‏ ‏.‏\hadithno{2100}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said: A guardian has no concern with a woman previously married and has no husband, and an orphan girl (i.e. virgin) must be consulted, her silence being her acceptance}}
\hadithdefcmd{abudawud}{2101}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْقَاسِمِ، عَنْ أَبِيهِ، عَنْ عَبْدِ الرَّحْمَنِ، وَمُجَمِّعٍ، ابْنَىْ يَزِيدَ الأَنْصَارِيَّيْنِ عَنْ خَنْسَاءَ بِنْتِ خِدَامٍ الأَنْصَارِيَّةِ، أَنَّ أَبَاهَا، زَوَّجَهَا وَهِيَ ثَيِّبٌ فَكَرِهَتْ ذَلِكَ فَجَاءَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم فَذَكَرَتْ ذَلِكَ لَهُ فَرَدَّ نِكَاحَهَا ‏.‏\hadithno{2101}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5138)}\hadithtrans{Khansa’ daughter of Khidham al-Ansariyyah reports that when her father married her when she had previously been married and she disapproved of that she went to the Apostle of Allaah(ﷺ) and mentioned it to him. He (the Prophet) revoked her marriage}}
\hadithdefcmd{abudawud}{2102}{حَدَّثَنَا عَبْدُ الْوَاحِدِ بْنُ غِيَاثٍ، حَدَّثَنَا حَمَّادٌ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ أَبِي سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ أَبَا هِنْدٍ، حَجَمَ النَّبِيَّ صلى الله عليه وسلم فِي الْيَافُوخِ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ يَا بَنِي بَيَاضَةَ أَنْكِحُوا أَبَا هِنْدٍ وَانْكِحُوا إِلَيْهِ ‏"‏ ‏.‏ قَالَ ‏"‏ وَإِنْ كَانَ فِي شَىْءٍ مِمَّا تَدَاوَوْنَ بِهِ خَيْرٌ فَالْحِجَامَةُ ‏"‏ ‏.‏\hadithno{2102}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated AbuHurayrah: AbuHind cupped the Prophet (ﷺ) in the middle of his head. The Prophet (ﷺ) said: Banu Bayadah, marry AbuHind (to your daughter), and ask him to marry (his daughter) to you. He said: The best thing by which you treat yourself is cupping}}
\hadithdefcmd{abudawud}{2103}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، - الْمَعْنَى - قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ بْنِ مِقْسَمٍ الثَّقَفِيُّ، - مِنْ أَهْلِ الطَّائِفِ - حَدَّثَتْنِي سَارَّةُ بِنْتُ مِقْسَمٍ، أَنَّهَا سَمِعَتْ مَيْمُونَةَ بِنْتَ كَرْدَمٍ، قَالَتْ خَرَجْتُ مَعَ أَبِي فِي حَجَّةِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَرَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَدَنَا إِلَيْهِ أَبِي وَهُوَ عَلَى نَاقَةٍ لَهُ فَوَقَفَ لَهُ وَاسْتَمَعَ مِنْهُ وَمَعَهُ دِرَّةٌ كَدِرَّةِ الْكُتَّابِ فَسَمِعْتُ الأَعْرَابَ وَالنَّاسَ وَهُمْ يَقُولُونَ الطَّبْطَبِيَّةَ الطَّبْطَبِيَّةَ الطَّبْطَبِيَّةَ فَدَنَا إِلَيْهِ أَبِي فَأَخَذَ بِقَدَمِهِ فَأَقَرَّ لَهُ وَوَقَفَ عَلَيْهِ وَاسْتَمَعَ مِنْهُ فَقَالَ إِنِّي حَضَرْتُ جَيْشَ عِثْرَانَ - قَالَ ابْنُ الْمُثَنَّى جَيْشَ غِثْرَانَ - فَقَالَ طَارِقُ بْنُ الْمُرَقَّعِ مَنْ يُعْطِينِي رُمْحًا بِثَوَابِهِ قُلْتُ وَمَا ثَوَابُهُ قَالَ أُزَوِّجُهُ أَوَّلَ بِنْتٍ تَكُونُ لِي ‏.‏ فَأَعْطَيْتُهُ رُمْحِي ثُمَّ غِبْتُ عَنْهُ حَتَّى عَلِمْتُ أَنَّهُ قَدْ وُلِدَ لَهُ جَارِيَةٌ وَبَلَغَتْ ثُمَّ جِئْتُهُ فَقُلْتُ لَهُ أَهْلِي جَهِّزْهُنَّ إِلَىَّ ‏.‏ فَحَلَفَ أَنْ لاَ يَفْعَلَ حَتَّى أُصْدِقَهُ صَدَاقًا جَدِيدًا غَيْرَ الَّذِي كَانَ بَيْنِي وَبَيْنَهُ وَحَلَفْتُ لاَ أُصْدِقُ غَيْرَ الَّذِي أَعْطَيْتُهُ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ وَبِقَرْنِ أَىِّ النِّسَاءِ هِيَ الْيَوْمَ ‏"‏ ‏.‏ قَالَ قَدْ رَأَتِ الْقَتِيرَ ‏.‏ قَالَ ‏"‏ أَرَى أَنْ تَتْرُكَهَا ‏"‏ ‏.‏ قَالَ فَرَاعَنِي ذَلِكَ وَنَظَرْتُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَلَمَّا رَأَى ذَلِكَ مِنِّي قَالَ ‏"‏ لاَ تَأْثَمُ وَلاَ يَأْثَمُ صَاحِبُكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْقَتِيرُ الشَّيْبُ ‏.‏\hadithno{2103}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Maymunah, daughter of Kardam: I went out along with my father during the hajj performed by the Messenger of Allah (ﷺ). I saw the Messenger of Allah (ﷺ). My father came near him; he was riding his she-camel. He stopped there and listened to him. He had a whip like the whip of the teachers. I heard the Bedouin and the people saying: Keep away from the whip. My father came up to him. He caught hold of his foot and acknowledged him (his Prophethood). He stopped and listened to him. He then said: I participated in the army of Athran (in the pre-Islamic days). The narrator, Ibn al-Muthanna, said: Army of Gathran. Tariq ibn al-Muraqqa' said: Who will give me a lance and get a reward? I asked: What is its reward? He replied: I shall marry him to my first daughter born to me. So I gave him my lance and then disappeared from him till I knew that a daughter was born to him and she came of age. I then came to him and said: Send my wife to me. He swore that he would not do that until I fixed a dower afresh other than that agreed between me and him, and I swore that I should not give him the dower other than that I had given him before. The Messenger of Allah (ﷺ) said: How old is she now? He said: She has grown old. He said: I think you should leave her. He said: This put awe and fear into me, and I looked at the Messenger of Allah (ﷺ). When he felt this in me, he said: You will not be sinful, nor will your companion be sinful. Abu Dawud said: Qatir means old age}}
\hadithdefcmd{abudawud}{2104}{حَدَّثَنَا أَحْمَدُ بْنُ صَالِحٍ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي إِبْرَاهِيمُ بْنُ مَيْسَرَةَ، أَنَّ خَالَتَهُ، أَخْبَرَتْهُ عَنِ امْرَأَةٍ، قَالَتْ هِيَ مُصَدَّقَةٌ امْرَأَةُ صِدْقٍ قَالَتْ بَيْنَا أَبِي فِي غَزَاةٍ فِي الْجَاهِلِيَّةِ إِذْ رَمِضُوا فَقَالَ رَجُلٌ مَنْ يُعْطِينِي نَعْلَيْهِ وَأُنْكِحُهُ أَوَّلَ بِنْتٍ تُولَدُ لِي فَخَلَعَ أَبِي نَعْلَيْهِ فَأَلْقَاهُمَا إِلَيْهِ فَوُلِدَتْ لَهُ جَارِيَةٌ فَبَلَغَتْ وَذَكَرَ نَحْوَهُ وَلَمْ يَذْكُرْ قِصَّةَ الْقَتِيرِ ‏.‏\hadithno{2104}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Ibrahim bin Maisarah reported from his maternal aunt who reported on the authority of a woman called Mussaddaqah (a truthful woman). She said “In pre Islamic days, when my father participated in a battle the feet of the people burnt due to intense heat. Thereupon a man said “Who gives me his shoes, I shall marry him to my first daughter born to me. My father took off his shoes and there them before him. A girl was thereafter born to him and came of age.” The narrator then mentioned a similar story. But he did not mention that she had grown old}}
\hadithdefcmd{abudawud}{2105}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ مُحَمَّدٍ النُّفَيْلِيُّ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، حَدَّثَنَا يَزِيدُ بْنُ الْهَادِ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ أَبِي سَلَمَةَ، قَالَ سَأَلْتُ عَائِشَةَ - رضى الله عنها - عَنْ صَدَاقِ النَّبِيِّ صلى الله عليه وسلم قَالَتْ ثِنْتَا عَشْرَةَ أُوقِيَّةً وَنَشٌّ ‏.‏ فَقُلْتُ وَمَا نَشٌّ قَالَتْ نِصْفُ أُوقِيَّةٍ ‏.‏\hadithno{2105}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1426)}\hadithtrans{Abu Salamah said “I asked A’ishah about the dower given by the Apostle of Allaah(ﷺ). She said “It was twelve Uqiyahs and a nashsh”. I asked “What is nashsh?” She said it is half an uqiyah}}
\hadithdefcmd{abudawud}{2106}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ أَيُّوبَ، عَنْ مُحَمَّدٍ، عَنْ أَبِي الْعَجْفَاءِ السُّلَمِيِّ، قَالَ خَطَبَنَا عُمَرُ رَحِمَهُ اللَّهُ فَقَالَ أَلاَ لاَ تُغَالُوا بِصُدُقِ النِّسَاءِ فَإِنَّهَا لَوْ كَانَتْ مَكْرُمَةً فِي الدُّنْيَا أَوْ تَقْوَى عِنْدَ اللَّهِ لَكَانَ أَوْلاَكُمْ بِهَا النَّبِيُّ صلى الله عليه وسلم مَا أَصْدَقَ رَسُولُ اللَّهِ صلى الله عليه وسلم امْرَأَةً مِنْ نِسَائِهِ وَلاَ أُصْدِقَتِ امْرَأَةٌ مِنْ بَنَاتِهِ أَكْثَرَ مِنْ ثِنْتَىْ عَشْرَةَ أُوقِيَّةً ‏.‏\hadithno{2106}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{AbulAjfa' as-Sulami said:Umar (Allah be pleased with him) delivered a speech to us and said: Do not go to extremes in giving women their dower, for if it represented honour in this world and piety in Allah's sight, the one of you most entitled to do so would have been the Prophet (ﷺ). The Messenger of Allah (ﷺ) did not marry any of his wives or gave any of his daughters in marriage for more than twelve uqiyahs}}
\hadithdefcmd{abudawud}{2107}{حَدَّثَنَا حَجَّاجُ بْنُ أَبِي يَعْقُوبَ الثَّقَفِيُّ، حَدَّثَنَا مُعَلَّى بْنُ مَنْصُورٍ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، حَدَّثَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ، عَنْ أُمِّ حَبِيبَةَ، أَنَّهَا كَانَتْ تَحْتَ عُبَيْدِ اللَّهِ بْنِ جَحْشٍ فَمَاتَ بِأَرْضِ الْحَبَشَةِ فَزَوَّجَهَا النَّجَاشِيُّ النَّبِيَّ صلى الله عليه وسلم وَأَمْهَرَهَا عنه أَرْبَعَةَ آلاَفٍ وَبَعَثَ بِهَا إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم مَعَ شُرَحْبِيلَ ابْنِ حَسَنَةَ ‏.‏ قَالَ أَبُو دَاوُدَ حَسَنَةُ هِيَ أُمُّهُ ‏.‏\hadithno{2107}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Urwah reported on the authority of Umm Habibah that she was married to Abdullah ibn Jahsh who died in Abyssinia, so the Negus married her to the Prophet (ﷺ) giving her on his behalf a dower of four thousand (dirhams). He sent her to the Messenger of Allah (ﷺ) with Shurahbil ibn Hasanah. AbuDawud said:Hasanah is his mother}}
\hadithdefcmd{abudawud}{2108}{حَدَّثَنَا مُحَمَّدُ بْنُ حَاتِمِ بْنِ بَزِيعٍ، حَدَّثَنَا عَلِيُّ بْنُ الْحَسَنِ بْنِ شَقِيقٍ، عَنِ ابْنِ الْمُبَارَكِ، عَنْ يُونُسَ، عَنِ الزُّهْرِيِّ، أَنَّ النَّجَاشِيَّ، زَوَّجَ أُمَّ حَبِيبَةَ بِنْتَ أَبِي سُفْيَانَ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم عَلَى صَدَاقٍ أَرْبَعَةِ آلاَفِ دِرْهَمٍ وَكَتَبَ بِذَلِكَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَبِلَ ‏.‏\hadithno{2108}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Az-Zuhri said:The Negus married Umm Habibah daughter of Abu Sufyan to the Messenger of Allah (ﷺ) for a dower of four thousand dirhams. He wrote it to the Messenger of Allah (ﷺ) who accepted it}}
\hadithdefcmd{abudawud}{2109}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ ثَابِتٍ الْبُنَانِيِّ، وَحُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم رَأَى عَبْدَ الرَّحْمَنِ بْنَ عَوْفٍ وَعَلَيْهِ رَدْعُ زَعْفَرَانٍ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ مَهْيَمْ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ تَزَوَّجْتُ امْرَأَةً ‏.‏ قَالَ ‏"‏ مَا أَصْدَقْتَهَا ‏"‏ ‏.‏ قَالَ وَزْنَ نَوَاةٍ مِنْ ذَهَبٍ ‏.‏ قَالَ ‏"‏ أَوْلِمْ وَلَوْ بِشَاةٍ ‏"‏ ‏.‏\hadithno{2109}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas:The Messenger of Allah (ﷺ) saw the trace of yellow on 'Abd al-Rahman b. 'Awf. The Prophet (ﷺ) said: What is this ? He replied: Messenger of Allah, I have married a woman. He asked: How much dower did you give her ? He said: A nawat weight of gold. He said: Hold a wedding feast, even if only with a sheep}}
\hadithdefcmd{abudawud}{2110}{حَدَّثَنَا إِسْحَاقُ بْنُ جِبْرِيلَ الْبَغْدَادِيُّ، أَخْبَرَنَا يَزِيدُ، أَخْبَرَنَا مُوسَى بْنُ مُسْلِمِ بْنِ رُومَانَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ أَعْطَى فِي صَدَاقِ امْرَأَةٍ مِلْءَ كَفَّيْهِ سَوِيقًا أَوْ تَمْرًا فَقَدِ اسْتَحَلَّ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ عَنْ صَالِحِ بْنِ رُومَانَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ مَوْقُوفًا وَرَوَاهُ أَبُو عَاصِمٍ عَنْ صَالِحِ بْنِ رُومَانَ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ قَالَ كُنَّا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم نَسْتَمْتِعُ بِالْقُبْضَةِ مِنَ الطَّعَامِ عَلَى مَعْنَى الْمُتْعَةِ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَاهُ ابْنُ جُرَيْجٍ عَنْ أَبِي الزُّبَيْرِ عَنْ جَابِرٍ عَلَى مَعْنَى أَبِي عَاصِمٍ ‏.‏\hadithno{2110}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir ibn Abdullah: The Prophet (ﷺ) said: If anyone gives as a dower to his wife two handfuls of flour or dates he has made her lawful for him. AbuDawud said: This tradition has been narrated by Abdur Rahman ibn Mahdi, from Salih ibn Ruman, from Abu al-Zubayr on the authority of Jabir as his own statement (not going back to the Prophet). It has also been transmitted by AbuAsim from Salih ibn Ruman , from AbuzZubayr on the authority of Jabir who said: During the lifetime of the Messenger of Allah (ﷺ) we used to contract temporary marriage for a handful of grain. Abu Dawud said: This tradition has also been transmitted by Ibn Juraij from Abu al-Zubair on the authority of Jabir similar to the one narrated by Abu 'Asim}}
\hadithdefcmd{abudawud}{2111}{حَدَّثَنِي الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ أَبِي حَازِمِ بْنِ دِينَارٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم جَاءَتْهُ امْرَأَةٌ فَقَالَتْ يَا رَسُولَ اللَّهِ إِنِّي قَدْ وَهَبْتُ نَفْسِي لَكَ ‏.‏ فَقَامَتْ قِيَامًا طَوِيلاً فَقَامَ رَجُلٌ فَقَالَ يَا رَسُولَ اللَّهِ زَوِّجْنِيهَا إِنْ لَمْ يَكُنْ لَكَ بِهَا حَاجَةٌ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ هَلْ عِنْدَكَ مِنْ شَىْءٍ تُصْدِقُهَا إِيَّاهُ ‏"‏ ‏.‏ فَقَالَ مَا عِنْدِي إِلاَّ إِزَارِي هَذَا ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّكَ إِنْ أَعْطَيْتَهَا إِزَارَكَ جَلَسْتَ وَلاَ إِزَارَ لَكَ فَالْتَمِسْ شَيْئًا ‏"‏ ‏.‏ قَالَ لاَ أَجِدُ شَيْئًا ‏.‏ قَالَ ‏"‏ فَالْتَمِسْ وَلَوْ خَاتَمًا مِنْ حَدِيدٍ ‏"‏ ‏.‏ فَالْتَمَسَ فَلَمْ يَجِدْ شَيْئًا فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ فَهَلْ مَعَكَ مِنَ الْقُرْآنِ شَىْءٌ ‏"‏ ‏.‏ قَالَ نَعَمْ سُورَةُ كَذَا وَسُورَةُ كَذَا ‏.‏ لِسُوَرٍ سَمَّاهَا ‏.‏ فَقَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ قَدْ زَوَّجْتُكَهَا بِمَا مَعَكَ مِنَ الْقُرْآنِ ‏"‏ ‏.‏\hadithno{2111}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2310) Sahih Muslim (1425)}\hadithtrans{Narrated Sahl b. Sa'd al-Sa'idi :A woman came to the Messenger of Allah (ﷺ) and said: Messenger of Allah, I have offered myself to you. When she stood for a long time, a man got up and said: Messenger of Allah, marry her to me if you have no need for her. The Messenger of Allah (ﷺ) asked: Have you anything to give her as dower ? He replied: I have nothing by this lower garment of mine. The Messenger of Allah (ﷺ) said: If you give your lower garment, you will sit while you have no lower garment. So look for something else. He said: I do not find anything. He said: Look for something, even though it should be an iron ring. The man sought it but found nothing. The Messenger of Allah (ﷺ) said: Do you know anything from the Qur'an ? He said: Yes, I know surah so and so, which he named. The Messenger of Allah (ﷺ) said: I have given you her in marriage for the part of the Qur'an which you know}}
\hadithdefcmd{abudawud}{2112}{حَدَّثَنَا أَحْمَدُ بْنُ حَفْصِ بْنِ عَبْدِ اللَّهِ، حَدَّثَنِي أَبِي حَفْصُ بْنُ عَبْدِ اللَّهِ، حَدَّثَنِي إِبْرَاهِيمُ بْنُ طَهْمَانَ، عَنِ الْحَجَّاجِ بْنِ الْحَجَّاجِ الْبَاهِلِيِّ، عَنْ عِسْلٍ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنْ أَبِي هُرَيْرَةَ، نَحْوَ هَذِهِ الْقِصَّةِ لَمْ يَذْكُرِ الإِزَارَ وَالْخَاتَمَ فَقَالَ ‏"‏ مَا تَحْفَظُ مِنَ الْقُرْآنِ ‏"‏ ‏.‏ قَالَ سُورَةَ الْبَقَرَةِ أَوِ الَّتِي تَلِيهَا ‏.‏ قَالَ ‏"‏ فَقُمْ فَعَلِّمْهَا عِشْرِينَ آيَةً وَهِيَ امْرَأَتُكَ ‏"‏ ‏.‏\hadithno{2112}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A tradition similar to the one narrated above has also been transmitted by Abu Hurairah through a different chain of narrators. This version does not mention the lower garment and iron ring. He (the Prophet) said:How much do you memorize from Qur'an? He said: Surat al-Baqarah or the one that follows it. He said: Stand up and teach her twenty verses: she is your wife}}
\hadithdefcmd{abudawud}{2113}{حَدَّثَنَا هَارُونُ بْنُ زَيْدِ بْنِ أَبِي الزَّرْقَاءِ، حَدَّثَنَا أَبِي، حَدَّثَنَا مُحَمَّدُ بْنُ رَاشِدٍ، عَنْ مَكْحُولٍ، نَحْوَ خَبَرِ سَهْلٍ قَالَ وَكَانَ مَكْحُولٌ يَقُولُ لَيْسَ ذَلِكَ لأَحَدٍ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2113}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Makhul has also transmitted a tradition like the one narrated by Sahl (b. Sa'd al-Sa'idi). Makhul used to say:This is not lawful for anyone after the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{2114}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ سُفْيَانَ، عَنْ فِرَاسٍ، عَنِ الشَّعْبِيِّ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، فِي رَجُلٍ تَزَوَّجَ امْرَأَةً فَمَاتَ عَنْهَا وَلَمْ يَدْخُلْ بِهَا وَلَمْ يَفْرِضْ لَهَا الصَّدَاقَ فَقَالَ لَهَا الصَّدَاقُ كَامِلاً وَعَلَيْهَا الْعِدَّةُ وَلَهَا الْمِيرَاثُ ‏.‏ فَقَالَ مَعْقِلُ بْنُ سِنَانٍ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَى بِهِ فِي بِرْوَعَ بِنْتِ وَاشِقٍ ‏.‏\hadithno{2114}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Mas'ud: Masruq said on the authority of Abdullah ibn Mas'ud: Abdullah (ibn Mas'ud ) was asked about a man who had married a woman without cohabiting with her or fixing any dower for her till he died. Ibn Mas'ud said: She should receive the full dower (as given to women of her class), observe the waiting period ('Iddah), and have her share of inheritance. Thereupon Ma'qil ibn Sinan said: I heard the Messenger of Allah (ﷺ) giving the same decision regarding Birwa' daughter of Washiq (as the decision you have given)}}
\hadithdefcmd{abudawud}{2115}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، وَابْنُ، مَهْدِيٍّ عَنْ سُفْيَانَ، عَنْ مَنْصُورٍ، عَنْ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ، عَنْ عَبْدِ اللَّهِ، وَسَاقَ، عُثْمَانُ مِثْلَهُ ‏.‏\hadithno{2115}\hadithgrade{Al-Albani: Daif; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by 'Alqamah on the authority of 'Abd Allah. 'Uthman (b. Abi Shaibah) narrated a similar tradition}}
\hadithdefcmd{abudawud}{2116}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدُ بْنُ أَبِي عَرُوبَةَ، عَنْ قَتَادَةَ، عَنْ خِلاَسٍ، وَأَبِي، حَسَّانَ عَنْ عَبْدِ اللَّهِ بْنِ عُتْبَةَ بْنِ مَسْعُودٍ، أَنَّ عَبْدَ اللَّهِ بْنَ مَسْعُودٍ، أُتِيَ فِي رَجُلٍ بِهَذَا الْخَبَرِ قَالَ فَاخْتَلَفُوا إِلَيْهِ شَهْرًا أَوْ قَالَ مَرَّاتٍ قَالَ فَإِنِّي أَقُولُ فِيهَا إِنَّ لَهَا صَدَاقًا كَصَدَاقِ نِسَائِهَا لاَ وَكْسَ وَلاَ شَطَطَ وَإِنَّ لَهَا الْمِيرَاثَ وَعَلَيْهَا الْعِدَّةُ فَإِنْ يَكُ صَوَابًا فَمِنَ اللَّهِ وَإِنْ يَكُنْ خَطَأً فَمِنِّي وَمِنَ الشَّيْطَانِ وَاللَّهُ وَرَسُولُهُ بَرِيئَانِ ‏.‏ فَقَامَ نَاسٌ مِنْ أَشْجَعَ فِيهِمُ الْجَرَّاحُ وَأَبُو سِنَانٍ فَقَالُوا يَا ابْنَ مَسْعُودٍ نَحْنُ نَشْهَدُ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَضَاهَا فِينَا فِي بِرْوَعَ بِنْتِ وَاشِقٍ وَإِنَّ زَوْجَهَا هِلاَلُ بْنُ مُرَّةَ الأَشْجَعِيُّ كَمَا قَضَيْتَ ‏.‏ قَالَ فَفَرِحَ عَبْدُ اللَّهِ بْنُ مَسْعُودٍ فَرَحًا شَدِيدًا حِينَ وَافَقَ قَضَاؤُهُ قَضَاءَ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2116}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Mas'ud: Abdullah ibn Utbah ibn Mas'ud said: Abdullah ibn Mas'ud was informed of this story of a man. The people continued to visit him for a month or visited him many times (the narrator was not sure). He said: In this matter I hold the opinion that she should receive the type of dower given to women of her class with no diminution or excess, observe the waiting period ('iddah) and have her share of inheritance. If it is erroneous, that is from me and from Satan. Allah and His Apostle are free from its responsibility. Some people from Ashja' got up; among them were al-Jarrah and AbuSinan. They said: Ibn Mas'ud, we bear witness that the Messenger of Allah (ﷺ) gave a decision for us regarding Birwa', daughter of Washiq, to the same effect as the decision you have given. Her husband was Hilal ibn Murrah al-Ashja'i. Thereupon Abdullah ibn Mas'ud was very pleased when his decision agreed with the decision of the Messenger of Allah (ﷺ)}}
\hadithdefcmd{abudawud}{2117}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى بْنِ فَارِسٍ الذُّهْلِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، وَعُمَرُ بْنُ الْخَطَّابِ، - قَالَ مُحَمَّدٌ - حَدَّثَنَا أَبُو الأَصْبَغِ الْجَزَرِيُّ عَبْدُ الْعَزِيزِ بْنُ يَحْيَى، أَخْبَرَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ أَبِي عَبْدِ الرَّحِيمِ، خَالِدِ بْنِ أَبِي يَزِيدَ عَنْ زَيْدِ بْنِ أَبِي أُنَيْسَةَ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ مَرْثَدِ بْنِ عَبْدِ اللَّهِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏"‏ أَتَرْضَى أَنْ أُزَوِّجَكَ فُلاَنَةَ ‏"‏ ‏.‏ قَالَ نَعَمْ ‏.‏ وَقَالَ لِلْمَرْأَةِ ‏"‏ أَتَرْضِينَ أَنْ أُزَوِّجَكِ فُلاَنًا ‏"‏ ‏.‏ قَالَتْ نَعَمْ ‏.‏ فَزَوَّجَ أَحَدُهُمَا صَاحِبَهُ فَدَخَلَ بِهَا الرَّجُلُ وَلَمْ يَفْرِضْ لَهَا صَدَاقًا وَلَمْ يُعْطِهَا شَيْئًا وَكَانَ مِمَّنْ شَهِدَ الْحُدَيْبِيَةَ وَكَانَ مَنْ شَهِدَ الْحُدَيْبِيَةَ لَهُ سَهْمٌ بِخَيْبَرَ فَلَمَّا حَضَرَتْهُ الْوَفَاةُ قَالَ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم زَوَّجَنِي فُلاَنَةَ وَلَمْ أَفْرِضْ لَهَا صَدَاقًا وَلَمْ أُعْطِهَا شَيْئًا وَإِنِّي أُشْهِدُكُمْ أَنِّي أَعْطَيْتُهَا مِنْ صَدَاقِهَا سَهْمِي بِخَيْبَرَ فَأَخَذَتْ سَهْمًا فَبَاعَتْهُ بِمِائَةِ أَلْفٍ ‏.‏ قَالَ أَبُو دَاوُدَ وَزَادَ عُمَرُ بْنُ الْخَطَّابِ - وَحَدِيثُهُ أَتَمُّ - فِي أَوَّلِ الْحَدِيثِ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ خَيْرُ النِّكَاحِ أَيْسَرُهُ ‏"‏ ‏.‏ وَقَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِلرَّجُلِ ثُمَّ سَاقَ مَعْنَاهُ ‏.‏ قَالَ أَبُو دَاوُدَ يُخَافُ أَنْ يَكُونَ هَذَا الْحَدِيثُ مُلْزَقًا لأَنَّ الأَمْرَ عَلَى غَيْرِ هَذَا ‏.‏\hadithno{2117}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Uqbah ibn Amir: The Prophet (ﷺ) said to a man: Would you like me to marry you to so-and-so? He said: Yes. He also said to the woman: Would you like me to marry you to so-and-so? She said: Yes. He then married one to the other. The man had sexual intercourse with her, but he did not fix any dower for her, nor did he give anything to her. He was one of those who participated in the expedition to al-Hudaybiyyah. One part of the expedition to al-Hudaybiyyah had a share in Khaybar. When he was nearing his death, he said: The Messenger of Allah (ﷺ) married me to so-and-so, and I did not fix a dower for her, nor did I give anything to her. I call upon you as witness that I have given my share in Khaybar as her dower. So she took the share and sold it for one lakh (of dirhams). Abu Dawud said: The version of 'Umar b. al-Khattab added in the beginning of this tradition, and his version is more perfect. He reported the Messenger of Allah (ﷺ) as saying: The best marriage is the one that is most easy. The Messenger of Allah (ﷺ) said to the man. The narrator then transmitted the rest of the tradition to the same effect. Abu Dawud said: I am afraid this tradition has been added later on, for the matter is otherwise}}
\hadithdefcmd{abudawud}{2118}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي عُبَيْدَةَ، عَنْ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، فِي خُطْبَةِ الْحَاجَةِ فِي النِّكَاحِ وَغَيْرِهِ ح وَحَدَّثَنَا مُحَمَّدُ بْنُ سُلَيْمَانَ الأَنْبَارِيُّ - الْمَعْنَى - حَدَّثَنَا وَكِيعٌ عَنْ إِسْرَائِيلَ عَنْ أَبِي إِسْحَاقَ عَنْ أَبِي الأَحْوَصِ وَأَبِي عُبَيْدَةَ عَنْ عَبْدِ اللَّهِ قَالَ عَلَّمَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم خُطْبَةَ الْحَاجَةِ ‏"‏ إِنَّ الْحَمْدَ لِلَّهِ نَسْتَعِينُهُ وَنَسْتَغْفِرُهُ وَنَعُوذُ بِهِ مِنْ شُرُورِ أَنْفُسِنَا مَنْ يَهْدِ اللَّهُ فَلاَ مُضِلَّ لَهُ وَمَنْ يُضْلِلْ فَلاَ هَادِيَ لَهُ وَأَشْهَدُ أَنْ لاَ إِلَهَ إِلاَّ اللَّهُ وَأَشْهَدُ أَنَّ مُحَمَّدًا عَبْدُهُ وَرَسُولُهُ يَا أَيُّهَا الَّذِينَ آمَنُوا ‏\{‏ اتَّقُوا اللَّهَ الَّذِي تَسَاءَلُونَ بِهِ وَالأَرْحَامَ إِنَّ اللَّهَ كَانَ عَلَيْكُمْ رَقِيبًا ‏\}‏ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ حَقَّ تُقَاتِهِ وَلاَ تَمُوتُنَّ إِلاَّ وَأَنْتُمْ مُسْلِمُونَ ‏\}‏ ‏\{‏ يَا أَيُّهَا الَّذِينَ آمَنُوا اتَّقُوا اللَّهَ وَقُولُوا قَوْلاً سَدِيدًا * يُصْلِحْ لَكُمْ أَعْمَالَكُمْ وَيَغْفِرْ لَكُمْ ذُنُوبَكُمْ وَمَنْ يُطِعِ اللَّهَ وَرَسُولَهُ فَقَدْ فَازَ فَوْزًا عَظِيمًا ‏\}‏ ‏.‏ لَمْ يَقُلْ مُحَمَّدُ بْنُ سُلَيْمَانَ إِنَّ ‏.‏\hadithno{2118}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: The Messenger of Allah (ﷺ) taught us the address in case of some need: Praise be to Allah from Whom we ask help and pardon, and in Whom we take refuge from the evils within ourselves. He whom Allah guides has no one who can lead him astray, and he whom He leads astray has no one to guide him. I testify that there is no god but Allah, and I testify that Muhammad is His servant and Apostle. "You who believe,...fear Allah by Whom you ask your mutual rights, and reverence the wombs. Allah has been watching you." ..."you who believe, fear Allah as He should be feared, and die only as Muslims" ...."you who believe, fear Allah as He should be feared, and die only as Muslims"....."you who believe, fear Allah and say what is true. He will make your deeds sound, and forgive your sins. He who obeys Allah and His Apostle has achieved a mighty success." The narrator, Muhammad ibn Sulayman, did mention the word "inna" (verily)}}
\hadithdefcmd{abudawud}{2119}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَاصِمٍ، حَدَّثَنَا عِمْرَانُ، عَنْ قَتَادَةَ، عَنْ عَبْدِ رَبِّهِ، عَنْ أَبِي عِيَاضٍ، عَنِ ابْنِ مَسْعُودٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا تَشَهَّدَ ذَكَرَ نَحْوَهُ وَقَالَ بَعْدَ قَوْلِهِ ‏"‏ وَرَسُولُهُ ‏"‏ ‏.‏ ‏"‏ أَرْسَلَهُ بِالْحَقِّ بَشِيرًا وَنَذِيرًا بَيْنَ يَدَىِ السَّاعَةِ مَنْ يُطِعِ اللَّهَ وَرَسُولَهُ فَقَدْ رَشَدَ وَمَنْ يَعْصِهِمَا فَإِنَّهُ لاَ يَضُرُّ إِلاَّ نَفْسَهُ وَلاَ يَضُرُّ اللَّهَ شَيْئًا ‏"‏ ‏.‏\hadithno{2119}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Mas'ud: When the Messenger of Allah (ﷺ) recited the tashahhud....He then narrated the same tradition. In this version after the word "and His Apostle" he added the words: "He has sent him in truth as a bearer of glad tidings and a warner before the Hour. He who obeys Allah and His Prophet is on the right path, and he who disobeys them does not harm anyone except himself, and he does not harm Allah to the least}}
\hadithdefcmd{abudawud}{2120}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا بَدَلُ بْنُ الْمُحَبَّرِ، أَخْبَرَنَا شُعْبَةُ، عَنِ الْعَلاَءِ ابْنِ أَخِي، شُعَيْبٍ الرَّازِيِّ عَنْ إِسْمَاعِيلَ بْنِ إِبْرَاهِيمَ، عَنْ رَجُلٍ، مِنْ بَنِي سُلَيْمٍ قَالَ خَطَبْتُ إِلَى النَّبِيِّ صلى الله عليه وسلم أُمَامَةَ بِنْتَ عَبْدِ الْمُطَّلِبِ فَأَنْكَحَنِي مِنْ غَيْرِ أَنْ يَتَشَهَّدَ ‏.‏\hadithno{2120}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Isma'il bin Ibrahim:On the authority of a man from Banu Sulaim: I asked the Prophet (ﷺ) to marry Umamah daughter of 'Abd al-Muttalib to me. So he married her to me without reciting the tashahhud (i.e. the sermon for marriage)}}
\hadithdefcmd{abudawud}{2121}{حَدَّثَنَا سُلَيْمَانُ بْنُ حَرْبٍ، وَأَبُو كَامِلٍ قَالاَ حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، قَالَتْ تَزَوَّجَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم وَأَنَا بِنْتُ سَبْعٍ - قَالَ سُلَيْمَانُ أَوْ سِتٍّ - وَدَخَلَ بِي وَأَنَا بِنْتُ تِسْعٍ ‏.‏\hadithno{2121}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (3896) Sahih Muslim (1422)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) married me when I was seven years old. The narrator Sulaiman said: or Six years. He had intercourse with me when I was nine years old}}
\hadithdefcmd{abudawud}{2122}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا يَحْيَى، عَنْ سُفْيَانَ، قَالَ حَدَّثَنِي مُحَمَّدُ بْنُ أَبِي بَكْرٍ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي بَكْرٍ، عَنْ أَبِيهِ، عَنْ أُمِّ سَلَمَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم لَمَّا تَزَوَّجَ أُمَّ سَلَمَةَ أَقَامَ عِنْدَهَا ثَلاَثًا ثُمَّ قَالَ ‏ "‏ لَيْسَ بِكِ عَلَى أَهْلِكِ هَوَانٌ إِنْ شِئْتِ سَبَّعْتُ لَكِ وَإِنْ سَبَّعْتُ لَكِ سَبَّعْتُ لِنِسَائِي ‏"‏ ‏.‏\hadithno{2122}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1460)}\hadithtrans{Abd al-Malik b. Abi Bakr reported from his father on the authority of Umm Salamah:When the Messenger of Allah (ﷺ) married Umm Salamah, he stayed with her three night, and said: Your people (i.e. clan) are not being humbled for you in my estimation. If you wish I shall stay with you seven nights; and if I stay with you seven nights, I shall stay with my other wives seven nights}}
\hadithdefcmd{abudawud}{2123}{حَدَّثَنَا وَهْبُ بْنُ بَقِيَّةَ، وَعُثْمَانُ بْنُ أَبِي شَيْبَةَ، عَنْ هُشَيْمٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم صَفِيَّةَ أَقَامَ عِنْدَهَا ثَلاَثًا ‏.‏ زَادَ عُثْمَانُ وَكَانَتْ ثَيِّبًا ‏.‏ وَقَالَ حَدَّثَنِي هُشَيْمٌ أَخْبَرَنَا حُمَيْدٌ أَخْبَرَنَا أَنَسٌ ‏.‏\hadithno{2123}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas bin Malik:When the Messenger of Allah (ﷺ) married Safiyyah, he stayed with her three nights. The narrator 'Uthman added: She was non virgin (previously married). He said: This tradition has been narrated to me by Hushaim, reported by Humaid, and transmitted by Anas}}
\hadithdefcmd{abudawud}{2124}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا هُشَيْمٌ، وَإِسْمَاعِيلُ ابْنُ عُلَيَّةَ، عَنْ خَالِدٍ الْحَذَّاءِ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ إِذَا تَزَوَّجَ الْبِكْرَ عَلَى الثَّيِّبِ أَقَامَ عِنْدَهَا سَبْعًا ‏.‏ وَإِذَا تَزَوَّجَ الثَّيِّبَ أَقَامَ عِنْدَهَا ثَلاَثًا ‏.‏ وَلَوْ قُلْتُ إِنَّهُ رَفَعَهُ لَصَدَقْتُ وَلَكِنَّهُ قَالَ السُّنَّةُ كَذَلِكَ ‏.‏\hadithno{2124}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5213) Sahih Muslim (1461)}\hadithtrans{Narrated Anas b. Malik :When a man who has a wife married a virgin he should stay with her seven nights ; if he marries to a woman who has been previously married he should stay with her three nights. (The narrator said:) If I say that he (Anas) narrated this tradition from the Prophet (ﷺ) I shall be true. But he said: The Sunnah is so-and-so}}
\hadithdefcmd{abudawud}{2125}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الطَّالْقَانِيُّ، حَدَّثَنَا عَبْدَةُ، حَدَّثَنَا سَعِيدٌ، عَنْ أَيُّوبَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ لَمَّا تَزَوَّجَ عَلِيٌّ فَاطِمَةَ قَالَ لَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعْطِهَا شَيْئًا ‏"‏ ‏.‏ قَالَ مَا عِنْدِي شَىْءٌ ‏.‏ قَالَ ‏"‏ أَيْنَ دِرْعُكَ الْحُطَمِيَّةُ ‏"‏ ‏.‏\hadithno{2125}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abdullah ibn Abbas: When Ali married Fatimah, the Prophet (ﷺ) said to him: Give her something. He said: I have nothing with me. He said: Where is your Hutamiyyah (coat of mail)}}
\hadithdefcmd{abudawud}{2126}{حَدَّثَنَا كَثِيرُ بْنُ عُبَيْدٍ الْحِمْصِيُّ، حَدَّثَنَا أَبُو حَيْوَةَ، عَنْ شُعَيْبٍ، - يَعْنِي ابْنَ أَبِي حَمْزَةَ - حَدَّثَنِي غَيْلاَنُ بْنُ أَنَسٍ، حَدَّثَنِي مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، عَنْ رَجُلٍ، مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَنَّ عَلِيًّا عَلَيْهِ السَّلاَمُ لَمَّا تَزَوَّجَ فَاطِمَةَ بِنْتَ رَسُولِ اللَّهِ صلى الله عليه وسلم وَرَضِيَ اللَّهُ عَنْهَا أَرَادَ أَنْ يَدْخُلَ بِهَا فَمَنَعَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى يُعْطِيَهَا شَيْئًا فَقَالَ يَا رَسُولَ اللَّهِ لَيْسَ لِي شَىْءٌ ‏.‏ فَقَالَ لَهُ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ أَعْطِهَا دِرْعَكَ ‏"‏ ‏.‏ فَأَعْطَاهَا دِرْعَهُ ثُمَّ دَخَلَ بِهَا ‏.‏\hadithno{2126}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Muhammad ibn Abdur Rahman ibn Thawban reported on the authority of a man from the Companions of the Prophet (ﷺ):When Ali married Fatimah, daughter of the Messenger of Allah (ﷺ), he intended to have intercourse with her. The Messenger of Allah (ﷺ) prohibited him to do so until he gave her something. Ali said: I have nothing with me, Messenger of Allah. The Prophet (ﷺ) said: Give her your coat of mail. So he gave her his coat of mail, and then cohabited with her}}
\hadithdefcmd{abudawud}{2127}{حَدَّثَنَا كَثِيرٌ، - يَعْنِي ابْنَ عُبَيْدٍ - حَدَّثَنَا أَبُو حَيْوَةَ، عَنْ شُعَيْبٍ، عَنْ غَيْلاَنَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، مِثْلَهُ ‏.‏\hadithno{2127}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{A similar tradition has also been transmitted by Ibn 'Abbas through a different chain of narrators}}
\hadithdefcmd{abudawud}{2128}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ الْبَزَّارُ، حَدَّثَنَا شَرِيكٌ، عَنْ مَنْصُورٍ، عَنْ طَلْحَةَ، عَنْ خَيْثَمَةَ، عَنْ عَائِشَةَ، قَالَتْ أَمَرَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ أُدْخِلَ امْرَأَةً عَلَى زَوْجِهَا قَبْلَ أَنْ يُعْطِيَهَا شَيْئًا ‏.‏ قَالَ أَبُو دَاوُدَ خَيْثَمَةُ لَمْ يَسْمَعْ مِنْ عَائِشَةَ ‏.‏\hadithno{2128}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) commanded me to send a woman to her husband before he gave something to her. Abu Dawud said: The narrator Khaithamah did not hear (any tradition) from 'Aishah}}
\hadithdefcmd{abudawud}{2129}{حَدَّثَنَا مُحَمَّدُ بْنُ مَعْمَرٍ، حَدَّثَنَا مُحَمَّدُ بْنُ بَكْرٍ الْبُرْسَانِيُّ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَيُّمَا امْرَأَةٍ نُكِحَتْ عَلَى صَدَاقٍ أَوْ حِبَاءٍ أَوْ عِدَةٍ قَبْلَ عِصْمَةِ النِّكَاحِ فَهُوَ لَهَا وَمَا كَانَ بَعْدَ عِصْمَةِ النِّكَاحِ فَهُوَ لِمَنْ أُعْطِيَهُ وَأَحَقُّ مَا أُكْرِمَ عَلَيْهِ الرَّجُلُ ابْنَتُهُ أَوْ أُخْتُهُ ‏"‏ ‏.‏\hadithno{2129}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Amr b. Shu'aib on his father's authority said that his grandfather reported The Messenger of Allah (ﷺ) said:A woman who marries on a dower or a reward or a promise before the solemnisation of marriage is entitled to it; and whatever is fixed for her after solemnisation of marriage belongs to whom it is given. A man is more entitled to receive a thing given as a gift on account of his daughter or sister (than other kinds of gifts)}}
\hadithdefcmd{abudawud}{2130}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْعَزِيزِ، - يَعْنِي ابْنَ مُحَمَّدٍ - عَنْ سُهَيْلٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ إِذَا رَفَّأَ الإِنْسَانَ إِذَا تَزَوَّجَ قَالَ ‏ "‏ بَارَكَ اللَّهُ لَكَ وَبَارَكَ عَلَيْكَ وَجَمَعَ بَيْنَكُمَا فِي خَيْرٍ ‏"‏ ‏.‏\hadithno{2130}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated AbuHurayrah: When the Prophet (ﷺ) congratulated a man on his marriage, he said: May Allah bless for you, and may He bless on you, and combine both of you in good (works)}}
\hadithdefcmd{abudawud}{2131}{حَدَّثَنَا مَخْلَدُ بْنُ خَالِدٍ، وَالْحَسَنُ بْنُ عَلِيٍّ، وَمُحَمَّدُ بْنُ أَبِي السَّرِيِّ، - الْمَعْنَى - قَالُوا حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا ابْنُ جُرَيْجٍ، عَنْ صَفْوَانَ بْنِ سُلَيْمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ رَجُلٍ، مِنَ الأَنْصَارِ - قَالَ ابْنُ أَبِي السَّرِيِّ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَلَمْ يَقُلْ مِنَ الأَنْصَارِ ثُمَّ اتَّفَقُوا - يُقَالُ لَهُ بَصْرَةُ قَالَ تَزَوَّجْتُ امْرَأَةً بِكْرًا فِي سِتْرِهَا فَدَخَلْتُ عَلَيْهَا فَإِذَا هِيَ حُبْلَى فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَهَا الصَّدَاقُ بِمَا اسْتَحْلَلْتَ مِنْ فَرْجِهَا وَالْوَلَدُ عَبْدٌ لَكَ فَإِذَا وَلَدَتْ ‏"‏ ‏.‏ قَالَ الْحَسَنُ ‏"‏ فَاجْلِدْهَا ‏"‏ ‏.‏ وَقَالَ ابْنُ أَبِي السَّرِيِّ ‏"‏ فَاجْلِدُوهَا ‏"‏ ‏.‏ أَوْ قَالَ ‏"‏ فَحُدُّوهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى هَذَا الْحَدِيثَ قَتَادَةُ عَنْ سَعِيدِ بْنِ يَزِيدَ عَنِ ابْنِ الْمُسَيَّبِ وَرَوَاهُ يَحْيَى بْنُ أَبِي كَثِيرٍ عَنْ يَزِيدَ بْنِ نُعَيْمٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ وَعَطَاءٌ الْخُرَاسَانِيُّ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ أَرْسَلُوهُ كُلُّهُمْ ‏.‏ وَفِي حَدِيثِ يَحْيَى بْنِ أَبِي كَثِيرٍ أَنَّ بَصْرَةَ بْنَ أَكْثَمَ نَكَحَ امْرَأَةً وَكُلُّهُمْ قَالَ فِي حَدِيثِهِ جَعَلَ الْوَلَدَ عَبْدًا لَهُ ‏.‏\hadithno{2131}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{A man from the Ansar called Basrah said:I married a virgin woman in her veil. When I entered upon her, I found her pregnant. (I mentioned this to the Prophet). The Prophet (ﷺ) said: She will get the dower, for you made her vagina lawful for you. The child will be your slave. When she has begotten (a child), flog her (according to the version of al-Hasan). The version of Ibn AbusSari has: You people, flog her, or said: inflict hard punishment on him. Abu Dawud said: This tradition has been transmitted by Qatadah from Sa'd b. Yazid on the authority of Ibn al-Musayyab in a similar way. This tradition has been narrated by Yahya b. Abi Kathir from Yazid b. Nu'aim from Sa'id b. al-Musayyab, and 'Ata al-Khurasani narrated it from Sa'id b. al-Musayyab ; they all narrated this tradition from the Prophet (ﷺ) omitting the link of the Companion (i.e. a mursal tradition). The version of Yahya b. Abi Kathir has: Basrah b. Aktham married a woman. The agreed version has: He made the child his servant}}
\hadithdefcmd{abudawud}{2132}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، حَدَّثَنَا عَلِيٌّ، - يَعْنِي ابْنَ الْمُبَارَكِ - عَنْ يَحْيَى، عَنْ يَزِيدَ بْنِ نُعَيْمٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ رَجُلاً، يُقَالُ لَهُ بَصْرَةُ بْنُ أَكْثَمَ نَكَحَ امْرَأَةً فَذَكَرَ مَعْنَاهُ ‏.‏ وَزَادَ وَفَرَّقَ بَيْنَهُمَا ‏.‏ وَحَدِيثُ ابْنِ جُرَيْجٍ أَتَمُّ ‏.‏\hadithno{2132}\hadithgrade{Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Daif}\hadithtrans{Sa'id b. al-Musayyab said:A man called Basrah b. Akhtam married a woman. The narrator then reported the rest of the tradition to the same effect. This version added: And he separated them. The tradition narrated by Ibn Juraij is perfect}}
\hadithdefcmd{abudawud}{2133}{حَدَّثَنَا أَبُو الْوَلِيدِ الطَّيَالِسِيُّ، حَدَّثَنَا هَمَّامٌ، حَدَّثَنَا قَتَادَةُ، عَنِ النَّضْرِ بْنِ أَنَسٍ، عَنْ بَشِيرِ بْنِ نَهِيكٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ كَانَتْ لَهُ امْرَأَتَانِ فَمَالَ إِلَى إِحْدَاهُمَا جَاءَ يَوْمَ الْقِيَامَةِ وَشِقُّهُ مَائِلٌ ‏"‏ ‏.‏\hadithno{2133}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: When a man has two wives and he is inclined to one of them, he will come on the Day of resurrection with a side hanging down}}
\hadithdefcmd{abudawud}{2134}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ أَيُّوبَ، عَنْ أَبِي قِلاَبَةَ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ الْخَطْمِيِّ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَقْسِمُ فَيَعْدِلُ وَيَقُولُ ‏ "‏ اللَّهُمَّ هَذَا قَسْمِي فِيمَا أَمْلِكُ فَلاَ تَلُمْنِي فِيمَا تَمْلِكُ وَلاَ أَمْلِكُ ‏"‏ ‏.‏ يَعْنِي الْقَلْبَ ‏.‏\hadithno{2134}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Aisha, Ummul Mu'minin: The Messenger of Allah (ﷺ) used to divide his time equally and said: O Allah, this is my division concerning what I control, so do not blame me concerning what You control and I do not. Abu Dawud said: By it meant the heart}}
\hadithdefcmd{abudawud}{2135}{حَدَّثَنَا أَحْمَدُ بْنُ يُونُسَ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، - يَعْنِي ابْنَ أَبِي الزِّنَادِ - عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، قَالَ قَالَتْ عَائِشَةُ يَا ابْنَ أُخْتِي كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم لاَ يُفَضِّلُ بَعْضَنَا عَلَى بَعْضٍ فِي الْقَسْمِ مِنْ مُكْثِهِ عِنْدَنَا وَكَانَ قَلَّ يَوْمٌ إِلاَّ وَهُوَ يَطُوفُ عَلَيْنَا جَمِيعًا فَيَدْنُو مِنْ كُلِّ امْرَأَةٍ مِنْ غَيْرِ مَسِيسٍ حَتَّى يَبْلُغَ إِلَى الَّتِي هُوَ يَوْمُهَا فَيَبِيتُ عِنْدَهَا وَلْقَدْ قَالَتْ سَوْدَةُ بِنْتُ زَمْعَةَ حِينَ أَسَنَّتْ وَفَرِقَتْ أَنْ يُفَارِقَهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَا رَسُولَ اللَّهِ يَوْمِي لِعَائِشَةَ ‏.‏ فَقَبِلَ ذَلِكَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْهَا قَالَتْ نَقُولُ فِي ذَلِكَ أَنْزَلَ اللَّهُ تَعَالَى وَفِي أَشْبَاهِهَا أُرَاهُ قَالَ ‏\{‏ وَإِنِ امْرَأَةٌ خَافَتْ مِنْ بَعْلِهَا نُشُوزًا ‏\}‏ ‏.‏\hadithno{2135}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Hisham b. 'Urwah:On the authority of his father that 'Aishah said: O my nephew, the Messenger of Allah (ﷺ) did not prefer one of us to the other in respect of his division of the time of his staying with us. It was very rare that he did not visit us any day (i.e. he visited all of us every day). He would come near each of his wives without having intercourse with her until he reached the one who had her day and passed his night with her. When Saudah daughter of Zam'ah became old and feared that the Messenger of Allah (ﷺ) would divorce her, she said: Messenger of Allah, I give to 'Aishah the day you visit me. The Messenger of Allah (ﷺ) accepted it from her. She said: We think that Allah, the Exalted, revealed about this or similar matter the Qur'anic verse: "If a wife fears cruelty or desertion on her husband's part...." [4:]}}
\hadithdefcmd{abudawud}{2136}{حَدَّثَنَا يَحْيَى بْنُ مَعِينٍ، وَمُحَمَّدُ بْنُ عِيسَى، - الْمَعْنَى - قَالاَ حَدَّثَنَا عَبَّادُ بْنُ عَبَّادٍ، عَنْ عَاصِمٍ، عَنْ مُعَاذَةَ، عَنْ عَائِشَةَ، قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَسْتَأْذِنُنَا إِذَا كَانَ فِي يَوْمِ الْمَرْأَةِ مِنَّا بَعْدَ مَا نَزَلَتْ ‏\{‏ تُرْجِي مَنْ تَشَاءُ مِنْهُنَّ وَتُؤْوِي إِلَيْكَ مَنْ تَشَاءُ ‏\}‏ قَالَتْ مُعَاذَةُ فَقُلْتُ لَهَا مَا كُنْتِ تَقُولِينَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم قَالَتْ كُنْتُ أَقُولُ إِنْ كَانَ ذَلِكَ إِلَىَّ لَمْ أُوثِرْ أَحَدًا عَلَى نَفْسِي ‏.‏\hadithno{2136}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Muslim (1476)}\hadithtrans{Narrated 'Aishah:The Messenger of Allah (ﷺ) used to aske our permission on the day he had to stay with one of his wives (by turns) after the following Qur'anic verse was revealed: "You may distance those whom you like, and draw close to those whom you like" [33:51]. The narrator Mu'adhah said: I said to her: What did you say to the Messenger of Allah (ﷺ) ? She said: I used to say: If had an option for that, I would not preferred anyone to myself}}
\hadithdefcmd{abudawud}{2137}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا مَرْحُومُ بْنُ عَبْدِ الْعَزِيزِ الْعَطَّارُ، حَدَّثَنِي أَبُو عِمْرَانَ الْجَوْنِيُّ، عَنْ يَزِيدَ بْنِ بَابَنُوسَ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ إِلَى النِّسَاءِ - تَعْنِي فِي مَرَضِهِ - فَاجْتَمَعْنَ فَقَالَ ‏ "‏ إِنِّي لاَ أَسْتَطِيعُ أَنْ أَدُورَ بَيْنَكُنَّ فَإِنْ رَأَيْتُنَّ أَنْ تَأْذَنَّ لِيَ فَأَكُونَ عِنْدَ عَائِشَةَ فَعَلْتُنَّ ‏"‏ ‏.‏ فَأَذِنَّ لَهُ ‏.‏\hadithno{2137}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{A’ishah said The Apostle of Allaah(ﷺ) sent for his wives during his illness. When they got together, he(ﷺ) said “I am unable to visit all of you. If you think to permit me to stay with A’ishah you may do so.” So they permitted him (to stay with A’ishah)}}
\hadithdefcmd{abudawud}{2138}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، أَخْبَرَنَا ابْنُ وَهْبٍ، عَنْ يُونُسَ، عَنِ ابْنِ شِهَابٍ، أَنَّ عُرْوَةَ بْنَ الزُّبَيْرِ، حَدَّثَهُ أَنَّ عَائِشَةَ زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَرَادَ سَفَرًا أَقْرَعَ بَيْنَ نِسَائِهِ فَأَيَّتُهُنَّ خَرَجَ سَهْمُهَا خَرَجَ بِهَا مَعَهُ وَكَانَ يَقْسِمُ لِكُلِّ امْرَأَةٍ مِنْهُنَّ يَوْمَهَا وَلَيْلَتَهَا غَيْرَ أَنَّ سَوْدَةَ بِنْتَ زَمْعَةَ وَهَبَتْ يَوْمَهَا لِعَائِشَةَ ‏.‏\hadithno{2138}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2593، 2688)}\hadithtrans{A’ishah wife of the Prophet (ﷺ) reported “When the Apostle of Allaah(ﷺ) intended to go on a journey he cast lots amongst his wives and the one who was chosen by lot went on it with him. He divided his time, day and night (equally) for each of his wives except that Saudah daughter of Zam’ah gave her day to A’ishah}}
\hadithdefcmd{abudawud}{2139}{حَدَّثَنَا عِيسَى بْنُ حَمَّادٍ، أَخْبَرَنِي اللَّيْثُ، عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ أَبِي الْخَيْرِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ إِنَّ أَحَقَّ الشُّرُوطِ أَنْ تُوفُوا بِهِ مَا اسْتَحْلَلْتُمْ بِهِ الْفُرُوجَ ‏"‏ ‏.‏\hadithno{2139}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (2721) Sahih Muslim (1418)}\hadithtrans{‘Uqbah bin ‘Amir reported the Apostle of Allaah (ﷺ) as saying “The condition worthier to be fulfilled by you is the one by which you made the private parts (of your wife) lawful (for you)}}
\hadithdefcmd{abudawud}{2140}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا إِسْحَاقُ بْنُ يُوسُفَ، عَنْ شَرِيكٍ، عَنْ حُصَيْنٍ، عَنِ الشَّعْبِيِّ، عَنْ قَيْسِ بْنِ سَعْدٍ، قَالَ أَتَيْتُ الْحِيرَةَ فَرَأَيْتُهُمْ يَسْجُدُونَ لِمَرْزُبَانٍ لَهُمْ فَقُلْتُ رَسُولُ اللَّهِ أَحَقُّ أَنْ يُسْجَدَ لَهُ قَالَ فَأَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ إِنِّي أَتَيْتُ الْحِيرَةَ فَرَأَيْتُهُمْ يَسْجُدُونَ لِمَرْزُبَانٍ لَهُمْ فَأَنْتَ يَا رَسُولَ اللَّهِ أَحَقُّ أَنْ نَسْجُدَ لَكَ ‏.‏ قَالَ ‏"‏ أَرَأَيْتَ لَوْ مَرَرْتَ بِقَبْرِي أَكُنْتَ تَسْجُدُ لَهُ ‏"‏ ‏.‏ قَالَ قُلْتُ لاَ ‏.‏ قَالَ ‏"‏ فَلاَ تَفْعَلُوا لَوْ كُنْتُ آمِرًا أَحَدًا أَنْ يَسْجُدَ لأَحَدٍ لأَمَرْتُ النِّسَاءَ أَنْ يَسْجُدْنَ لأَزْوَاجِهِنَّ لِمَا جَعَلَ اللَّهُ لَهُمْ عَلَيْهِنَّ مِنَ الْحَقِّ ‏"‏ ‏.‏\hadithno{2140}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Qays ibn Sa'd: I went to al-Hirah and saw them (the people) prostrating themselves before a satrap of theirs, so I said: The Messenger of Allah (ﷺ) has most right to have prostration made before him. When I came to the Prophet (ﷺ), I said: I went to al-Hirah and saw them prostrating themselves before a satrap of theirs, but you have most right, Messenger of Allah, to have (people) prostrating themselves before you. He said: Tell me , if you were to pass my grave, would you prostrate yourself before it? I said: No. He then said: Do not do so. If I were to command anyone to make prostration before another I would command women to prostrate themselves before their husbands, because of the special right over them given to husbands by Allah}}
\hadithdefcmd{abudawud}{2141}{حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو الرَّازِيُّ، حَدَّثَنَا جَرِيرٌ، عَنِ الأَعْمَشِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا دَعَا الرَّجُلُ امْرَأَتَهُ إِلَى فِرَاشِهِ فَأَبَتْ فَلَمْ تَأْتِهِ فَبَاتَ غَضْبَانَ عَلَيْهَا لَعَنَتْهَا الْمَلاَئِكَةُ حَتَّى تُصْبِحَ ‏"‏ ‏.‏\hadithno{2141}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5193) Sahih Muslim (1436)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “When a man calls his wife to come to his bed and she refuses and does not come to him and he spends the night angry, the angels curse her till the morning.”}}
\hadithdefcmd{abudawud}{2142}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا أَبُو قَزَعَةَ الْبَاهِلِيُّ، عَنْ حَكِيمِ بْنِ مُعَاوِيَةَ الْقُشَيْرِيِّ، عَنْ أَبِيهِ، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ مَا حَقُّ زَوْجَةِ أَحَدِنَا عَلَيْهِ قَالَ ‏"‏ أَنْ تُطْعِمَهَا إِذَا طَعِمْتَ وَتَكْسُوَهَا إِذَا اكْتَسَيْتَ - أَوِ اكْتَسَبْتَ - وَلاَ تَضْرِبِ الْوَجْهَ وَلاَ تُقَبِّحْ وَلاَ تَهْجُرْ إِلاَّ فِي الْبَيْتِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ ‏"‏ وَلاَ تُقَبِّحْ ‏"‏ ‏.‏ أَنْ تَقُولَ قَبَّحَكِ اللَّهُ ‏.‏\hadithno{2142}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Mu'awiyah al-Qushayri: Mu'awiyah asked: Messenger of Allah, what is the right of the wife of one of us over him? He replied: That you should give her food when you eat, clothe her when you clothe yourself, do not strike her on the face, do not revile her or separate yourself from her except in the house. Abu Dawud said: The meaning of "do not revile her" is, as you say: "May Allah revile you}}
\hadithdefcmd{abudawud}{2143}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا بَهْزُ بْنُ حَكِيمٍ، حَدَّثَنِي أَبِي، عَنْ جَدِّي، قَالَ قُلْتُ يَا رَسُولَ اللَّهِ نِسَاؤُنَا مَا نَأْتِي مِنْهُنَّ وَمَا نَذَرُ قَالَ ‏"‏ ائْتِ حَرْثَكَ أَنَّى شِئْتَ وَأَطْعِمْهَا إِذَا طَعِمْتَ وَاكْسُهَا إِذَا اكْتَسَيْتَ وَلاَ تُقَبِّحِ الْوَجْهَ وَلاَ تَضْرِبْ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ رَوَى شُعْبَةُ ‏"‏ تُطْعِمُهَا إِذَا طَعِمْتَ وَتَكْسُوهَا إِذَا اكْتَسَيْتَ ‏"‏ ‏.‏\hadithno{2143}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Bahz bin Hakim reported on the authority of his father from his grandfather (Mu'awiyah ibn Haydah) as saying:I said: Messenger of Allah, how should we approach our wives and how should we leave them? He replied: Approach your tilth when or how you will, give her (your wife) food when you take food, clothe when you clothe yourself, do not revile her face, and do not beat her. Abu Dawud said: The version of Shu'bah has: That you give her food when you have food yourself, and that you clothe her when you clothe yourself}}
\hadithdefcmd{abudawud}{2144}{أَخْبَرَنِي أَحْمَدُ بْنُ يُوسُفَ الْمُهَلَّبِيُّ النَّيْسَابُورِيُّ، حَدَّثَنَا عُمَرُ بْنُ عَبْدِ اللَّهِ بْنِ رَزِينٍ، حَدَّثَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنْ دَاوُدَ الْوَرَّاقِ، عَنْ سَعِيدِ بْنِ حَكِيمٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، مُعَاوِيَةَ الْقُشَيْرِيِّ قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ فَقُلْتُ مَا تَقُولُ فِي نِسَائِنَا قَالَ ‏ "‏ أَطْعِمُوهُنَّ مِمَّا تَأْكُلُونَ وَاكْسُوهُنَّ مِمَّا تَكْتَسُونَ وَلاَ تَضْرِبُوهُنَّ وَلاَ تُقَبِّحُوهُنَّ ‏"‏ ‏.‏\hadithno{2144}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mu'awiyah al-Qushayri: I went to the Messenger of Allah (ﷺ) and asked him: What do you say (command) about our wives? He replied: Give them food what you have for yourself, and clothe them by which you clothe yourself, and do not beat them, and do not revile them}}
\hadithdefcmd{abudawud}{2145}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ عَلِيِّ بْنِ زَيْدٍ، عَنْ أَبِي حُرَّةَ الرَّقَاشِيِّ، عَنْ عَمِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ فَإِنْ خِفْتُمْ نُشُوزَهُنَّ فَاهْجُرُوهُنَّ فِي الْمَضَاجِعِ ‏"‏ ‏.‏ قَالَ حَمَّادٌ يَعْنِي النِّكَاحَ ‏.‏\hadithno{2145}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Abu Harrah Al Ruqashi reported on the authority of his uncle” The Prophet (ﷺ) said “If you fear the recalcitrance abandon them in their beds.” The narrator Hammad said “By abandonment he meant abandonment of intercourse.”}}
\hadithdefcmd{abudawud}{2146}{حَدَّثَنَا أَحْمَدُ بْنُ أَبِي خَلَفٍ، وَأَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنِ الزُّهْرِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، - قَالَ ابْنُ السَّرْحِ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ - عَنْ إِيَاسِ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي ذُبَابٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ لاَ تَضْرِبُوا إِمَاءَ اللَّهِ ‏"‏ ‏.‏ فَجَاءَ عُمَرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ذَئِرْنَ النِّسَاءُ عَلَى أَزْوَاجِهِنَّ ‏.‏ فَرَخَّصَ فِي ضَرْبِهِنَّ فَأَطَافَ بِآلِ رَسُولِ اللَّهِ صلى الله عليه وسلم نِسَاءٌ كَثِيرٌ يَشْكُونَ أَزْوَاجَهُنَّ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ لَقَدْ طَافَ بِآلِ مُحَمَّدٍ نِسَاءٌ كَثِيرٌ يَشْكُونَ أَزْوَاجَهُنَّ لَيْسَ أُولَئِكَ بِخِيَارِكُمْ ‏"‏ ‏.‏\hadithno{2146}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Iyas ibn Abdullah ibn Abu Dhubab reported the Messenger of Allah (ﷺ) as saying:Do not beat Allah's handmaidens, but when Umar came to the Messenger of Allah (ﷺ) and said: Women have become emboldened towards their husbands, he (the Prophet) gave permission to beat them. Then many women came round the family of the Messenger of Allah (ﷺ) complaining against their husbands. So the Messenger of Allah (ﷺ) said: Many women have gone round Muhammad's family complaining against their husbands. They are not the best among you}}
\hadithdefcmd{abudawud}{2147}{حَدَّثَنَا زُهَيْرُ بْنُ حَرْبٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ دَاوُدَ بْنِ عَبْدِ اللَّهِ الأَوْدِيِّ، عَنْ عَبْدِ الرَّحْمَنِ الْمُسْلِيِّ، عَنِ الأَشْعَثِ بْنِ قَيْسٍ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يُسْأَلُ الرَّجُلُ فِيمَا ضَرَبَ امْرَأَتَهُ ‏"‏ ‏.‏\hadithno{2147}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umar ibn al-Khattab: The Prophet (ﷺ) said: A man will not be asked as to why he beat his wife}}
\hadithdefcmd{abudawud}{2148}{حَدَّثَنَا مُحَمَّدُ بْنُ كَثِيرٍ، أَخْبَرَنَا سُفْيَانُ، حَدَّثَنِي يُونُسُ بْنُ عُبَيْدٍ، عَنْ عَمْرِو بْنِ سَعِيدٍ، عَنْ أَبِي زُرْعَةَ، عَنْ جَرِيرٍ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ نَظْرَةِ الْفَجْأَةِ فَقَالَ ‏ "‏ اصْرِفْ بَصَرَكَ ‏"‏ ‏.‏\hadithno{2148}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (2159)}\hadithtrans{Jarir said I asked the Apostle of Allaah(ﷺ) about an accidental glance (on a woman). He (ﷺ) said “Turn your eyes away.”}}
\hadithdefcmd{abudawud}{2149}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ مُوسَى الْفَزَارِيُّ، أَخْبَرَنَا شَرِيكٌ، عَنْ أَبِي رَبِيعَةَ الإِيَادِيِّ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم لِعَلِيٍّ ‏ "‏ يَا عَلِيُّ لاَ تُتْبِعِ النَّظْرَةَ النَّظْرَةَ فَإِنَّ لَكَ الأُولَى وَلَيْسَتْ لَكَ الآخِرَةُ ‏"‏ ‏.‏\hadithno{2149}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Narrated Buraydah ibn al-Hasib: The Prophet (ﷺ) said: to Ali: Do not give a second look, Ali, (because) while you are not to blame for the first, you have no right to the second}}
\hadithdefcmd{abudawud}{2150}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنِ ابْنِ مَسْعُودٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ تُبَاشِرُ الْمَرْأَةُ الْمَرْأَةَ لِتَنْعَتَهَا لِزَوْجِهَا كَأَنَّمَا يَنْظُرُ إِلَيْهَا ‏"‏ ‏.‏\hadithno{2150}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (5241)}\hadithtrans{Ibn Masu’d reported the Apostle of Allaah(ﷺ) as saying “ A woman should not rub her body directly with the body of another woman so that she describes it to her husband as if he were looking at her.”}}
\hadithdefcmd{abudawud}{2151}{حَدَّثَنَا مُسْلِمُ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا هِشَامٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى امْرَأَةً فَدَخَلَ عَلَى زَيْنَبَ بِنْتِ جَحْشٍ فَقَضَى حَاجَتَهُ مِنْهَا ثُمَّ خَرَجَ إِلَى أَصْحَابِهِ فَقَالَ لَهُمْ ‏ "‏ إِنَّ الْمَرْأَةَ تُقْبِلُ فِي صُورَةِ شَيْطَانٍ فَمَنْ وَجَدَ مِنْ ذَلِكَ شَيْئًا فَلْيَأْتِ أَهْلَهُ فَإِنَّهُ يُضْمِرُ مَا فِي نَفْسِهِ ‏"‏ ‏.‏\hadithno{2151}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Hasan Sahih; Zubair Ali Zai: Sahih Muslim (1403)}\hadithtrans{Jabir said “The Prophet (ﷺ) saw a woman so he entered upon Zainab daughter of Jahsh and had intercourse with her. He (ﷺ) then came out and said to his companions and said to them “A woman advances in the form of a devil. When one of you finds that he should go to his wife (and have intercourse with her) for that will repel what he is feeling}}
\hadithdefcmd{abudawud}{2152}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ، حَدَّثَنَا ابْنُ ثَوْرٍ، عَنْ مَعْمَرٍ، أَخْبَرَنَا ابْنُ طَاوُسٍ، عَنْ أَبِيهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَا رَأَيْتُ شَيْئًا أَشْبَهَ بِاللَّمَمِ مِمَّا قَالَ أَبُو هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏ "‏ إِنَّ اللَّهَ كَتَبَ عَلَى ابْنِ آدَمَ حَظَّهُ مِنَ الزِّنَا أَدْرَكَ ذَلِكَ لاَ مَحَالَةَ فَزِنَا الْعَيْنَيْنِ النَّظَرُ وَزِنَا اللِّسَانِ الْمَنْطِقُ وَالنَّفْسُ تَمَنَّى وَتَشْتَهِي وَالْفَرْجُ يُصَدِّقُ ذَلِكَ وَيُكَذِّبُهُ ‏"‏ ‏.‏\hadithno{2152}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (6243) Sahih Muslim (2657)}\hadithtrans{Ibn ‘Abbas said “I did not see anything more resembling to minor sins than what Abu Hurairah reported from the Prophet (ﷺ) who said “Allaah has decreed for the children of Adam a share in adultery, he will get it by all means, the adultery of eyes is looking; the adultery of tongue is speaking; the soul desires and has a passion; the private parts confirms or falsifies it.”}}
\hadithdefcmd{abudawud}{2153}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ لِكُلِّ ابْنِ آدَمَ حَظُّهُ مِنَ الزِّنَا ‏"‏ ‏.‏ بِهَذِهِ الْقِصَّةِ قَالَ ‏"‏ وَالْيَدَانِ تَزْنِيَانِ فَزِنَاهُمَا الْبَطْشُ وَالرِّجْلاَنِ تَزْنِيَانِ فَزِنَاهُمَا الْمَشْىُ وَالْفَمُ يَزْنِي فَزِنَاهُ الْقُبَلُ ‏"‏ ‏.‏\hadithno{2153}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih Sahih Muslim (2657)}\hadithtrans{Abu Hurairah reported the Prophet (ﷺ) as saying “ Every child of Adam has his share in adultery. He then narrated the rest of the tradition. This version goes “And the hands commit adultery; their adultery is catching; and the legs commit adultery; their adultery is walking; and the mouth commits adultery – its adultery is kissing.”}}
\hadithdefcmd{abudawud}{2154}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم بِهَذِهِ الْقِصَّةِ قَالَ ‏ "‏ وَالأُذُنُ زِنَاهَا الاِسْتِمَاعُ ‏"‏ ‏.‏\hadithno{2154}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{The aforesaid tradition has also been transmitted by Abu Hurairah through a different chain of narrators. This version adds “The fornication of ear is hearing.”}}
\hadithdefcmd{abudawud}{2155}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عُمَرَ بْنِ مَيْسَرَةَ، حَدَّثَنَا يَزِيدُ بْنُ زُرَيْعٍ، حَدَّثَنَا سَعِيدٌ، عَنْ قَتَادَةَ، عَنْ صَالِحٍ أَبِي الْخَلِيلِ، عَنْ أَبِي عَلْقَمَةَ الْهَاشِمِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ يَوْمَ حُنَيْنٍ بَعْثًا إِلَى أَوْطَاسٍ فَلَقُوا عَدُوَّهُمْ فَقَاتَلُوهُمْ فَظَهَرُوا عَلَيْهِمْ وَأَصَابُوا لَهُمْ سَبَايَا فَكَأَنَّ أُنَاسًا مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم تَحَرَّجُوا مِنْ غِشْيَانِهِنَّ مِنْ أَجْلِ أَزْوَاجِهِنَّ مِنَ الْمُشْرِكِينَ فَأَنْزَلَ اللَّهُ تَعَالَى فِي ذَلِكَ ‏\{‏ وَالْمُحْصَنَاتُ مِنَ النِّسَاءِ إِلاَّ مَا مَلَكَتْ أَيْمَانُكُمْ ‏\}‏ أَىْ فَهُنَّ لَهُمْ حَلاَلٌ إِذَا انْقَضَتْ عِدَّتُهُنَّ ‏.‏\hadithno{2155}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1456)}\hadithtrans{Abu Sa’id Al Khudri said “The Apostle of Allaah(ﷺ) sent a military expedition to Awtas on the occasion of the battle of Hunain. They met their enemy and fought with them. They defeated them and took them captives. Some of the Companions of Apostle of Allaah (ﷺ) were reluctant to have relations with the female captives because of their pagan husbands. So, Allaah the exalted sent down the Qur’anic verse “And all married women (are forbidden) unto you save those (captives) whom your right hand posses.” This is to say that they are lawful for them when they complete their waiting period}}
\hadithdefcmd{abudawud}{2156}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مِسْكِينٌ، حَدَّثَنَا شُعْبَةُ، عَنْ يَزِيدَ بْنِ خُمَيْرٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ جُبَيْرِ بْنِ نُفَيْرٍ، عَنْ أَبِيهِ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ فِي غَزْوَةٍ فَرَأَى امْرَأَةً مُجِحًّا فَقَالَ ‏"‏ لَعَلَّ صَاحِبَهَا أَلَمَّ بِهَا ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ فَقَالَ ‏"‏ لَقَدْ هَمَمْتُ أَنْ أَلْعَنَهُ لَعْنَةً تَدْخُلُ مَعَهُ فِي قَبْرِهِ كَيْفَ يُوَرِّثُهُ وَهُوَ لاَ يَحِلُّ لَهُ وَكَيْفَ يَسْتَخْدِمُهُ وَهُوَ لاَ يَحِلُّ لَهُ ‏"‏ ‏.‏\hadithno{2156}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1441)}\hadithtrans{Abu Al Darda said “The Apostle of Allaah(ﷺ) was in a battle. He saw a woman who was nearing the time when she was to deliver a child. “He said “Perhaps the master has intercourse with her.”. They(the people) said “Yes”. He said “I am inclined to invoke a curse on him which will enter his grave with him. How can he make it (the child) an heir when it is not lawful for him? How can he take it into his service when that is not lawful for him?”}}
\hadithdefcmd{abudawud}{2157}{حَدَّثَنَا عَمْرُو بْنُ عَوْنٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ قَيْسِ بْنِ وَهْبٍ، عَنْ أَبِي الْوَدَّاكِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، وَرَفَعَهُ، أَنَّهُ قَالَ فِي سَبَايَا أَوْطَاسٍ ‏ "‏ لاَ تُوطَأُ حَامِلٌ حَتَّى تَضَعَ وَلاَ غَيْرُ ذَاتِ حَمْلٍ حَتَّى تَحِيضَ حَيْضَةً ‏"‏ ‏.‏\hadithno{2157}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{Abu Sa’id Al Khudri traced to Prophet (ﷺ) the following statement regarding the captives taken at Atwas. There must be no intercourse with pregnant woman till she gives birth to her child or with the one who is not pregnant till she has had one menstrual period}}
\hadithdefcmd{abudawud}{2158}{حَدَّثَنَا النُّفَيْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، حَدَّثَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ أَبِي مَرْزُوقٍ، عَنْ حَنَشٍ الصَّنْعَانِيِّ، عَنْ رُوَيْفِعِ بْنِ ثَابِتٍ الأَنْصَارِيِّ، قَالَ قَامَ فِينَا خَطِيبًا قَالَ أَمَا إِنِّي لاَ أَقُولُ لَكُمْ إِلاَّ مَا سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ يَوْمَ حُنَيْنٍ قَالَ ‏"‏ لاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَسْقِيَ مَاءَهُ زَرْعَ غَيْرِهِ ‏"‏ ‏.‏ يَعْنِي إِتْيَانَ الْحَبَالَى ‏"‏ وَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَقَعَ عَلَى امْرَأَةٍ مِنَ السَّبْىِ حَتَّى يَسْتَبْرِئَهَا وَلاَ يَحِلُّ لاِمْرِئٍ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ أَنْ يَبِيعَ مَغْنَمًا حَتَّى يُقْسَمَ ‏"‏ ‏.‏\hadithno{2158}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ruwayfi' ibn Thabit al-Ansari: Should I tell you what I heard the Messenger of Allah (ﷺ) say on the day of Hunayn: It is not lawful for a man who believes in Allah and the last day to water what another has sown with his water (meaning intercourse with women who are pregnant); it is not lawful for a man who believes in Allah and the Last Day to have intercourse with a captive woman till she is free from a menstrual course; and it is not lawful for a man who believes in Allah and the Last Day to sell spoil till it is divided}}
\hadithdefcmd{abudawud}{2159}{حَدَّثَنَا سَعِيدُ بْنُ مَنْصُورٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ ابْنِ إِسْحَاقَ، بِهَذَا الْحَدِيثِ قَالَ ‏"‏ حَتَّى يَسْتَبْرِئَهَا بِحَيْضَةٍ ‏"‏ ‏.‏ زَادَ فِيهِ ‏\{‏ بِحَيْضَةٍ وَهُوَ وَهَمٌ مِنْ أَبِي مُعَاوِيَةَ، وَهُوَ صَحِيحٌ فِي حَدِيثِ أَبِي سَعِيدٍ زَادَ ‏\}‏ ‏"‏ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَرْكَبْ دَابَّةً مِنْ فَىْءِ الْمُسْلِمِينَ حَتَّى إِذَا أَعْجَفَهَا رَدَّهَا فِيهِ وَمَنْ كَانَ يُؤْمِنُ بِاللَّهِ وَالْيَوْمِ الآخِرِ فَلاَ يَلْبَسْ ثَوْبًا مِنْ فَىْءِ الْمُسْلِمِينَ حَتَّى إِذَا أَخْلَقَهُ رَدَّهُ فِيهِ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ الْحَيْضَةُ لَيْسَتْ بِمَحْفُوظَةٍ وَهُوَ وَهَمٌ مِنْ أَبِي مُعَاوِيَةَ ‏.‏\hadithno{2159}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{The aforesaid tradition has also been transmitted by Ibn Ishaq through a different chain of narrators. This version has the traditional word “a menstrual course” in the phrase “till she is free from a menstrual course”. This is a misunderstanding on the part of the narrator Abu Mu’awiyah. This is correct in the tradition of Abu Sa’id Al Khudri. This version has the additional words “he who believes in Allaah and the Last Day should not ride on a mount belonging to the spoil of Muslims and when he makes it emaciated returns it; he who believes in Allaah and the Last Day should not put on cloth belonging to the spoils of Muslims and when makes it old (shabby) returns it. Abu Dawud said “The word “menstrual course” is not guarded. This is a misunderstanding on the part of Abu Mu’awiyah”}}
\hadithdefcmd{abudawud}{2160}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو خَالِدٍ، - يَعْنِي سُلَيْمَانَ بْنَ حَيَّانَ - عَنِ ابْنِ عَجْلاَنَ، عَنْ عَمْرِو بْنِ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِذَا تَزَوَّجَ أَحَدُكُمُ امْرَأَةً أَوِ اشْتَرَى خَادِمًا فَلْيَقُلِ اللَّهُمَّ إِنِّي أَسْأَلُكَ خَيْرَهَا وَخَيْرَ مَا جَبَلْتَهَا عَلَيْهِ وَأَعُوذُ بِكَ مِنْ شَرِّهَا وَمِنْ شَرِّ مَا جَبَلْتَهَا عَلَيْهِ وَإِذَا اشْتَرَى بَعِيرًا فَلْيَأْخُذْ بِذِرْوَةِ سَنَامِهِ وَلْيَقُلْ مِثْلَ ذَلِكَ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ زَادَ أَبُو سَعِيدٍ ‏"‏ ثُمَّ لْيَأْخُذْ بِنَاصِيَتِهَا وَلْيَدْعُ بِالْبَرَكَةِ ‏"‏ ‏.‏ فِي الْمَرْأَةِ وَالْخَادِمِ ‏.‏\hadithno{2160}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Amr b. Shu'aib on his father's authority said that his grandfather (Abdullah ibn Amr ibn al-'As) reported the Prophet (ﷺ) said:If one of you marries a woman or buys a slave, he should say: "O Allah, I ask You for the good in her, and in the disposition You have given her; I take refuge in You from the evil in her, and in the disposition You have given her." When he buys a camel, he should take hold of the top of its hump and say the same kind of thing. Abu Dawud said: Abu Sa'id added the following words in his version: He should then tale hold of her forelock and pray for blessing in the case of a woman or a slave}}
\hadithdefcmd{abudawud}{2161}{حَدَّثَنَا مُحَمَّدُ بْنُ عِيسَى، حَدَّثَنَا جَرِيرٌ، عَنْ مَنْصُورٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ كُرَيْبٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ قَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ لَوْ أَنَّ أَحَدَكُمْ إِذَا أَرَادَ أَنْ يَأْتِيَ أَهْلَهُ قَالَ بِسْمِ اللَّهِ اللَّهُمَّ جَنِّبْنَا الشَّيْطَانَ وَجَنِّبِ الشَّيْطَانَ مَا رَزَقْتَنَا ثُمَّ قُدِّرَ أَنْ يَكُونَ بَيْنَهُمَا وَلَدٌ فِي ذَلِكَ لَمْ يَضُرَّهُ شَيْطَانٌ أَبَدًا ‏"‏ ‏.‏\hadithno{2161}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (5165) Sahih Muslim (1434)}\hadithtrans{Ibn ‘Abbas reported the Prophet (ﷺ) as saying “If anyone who means to have intercourse with his wife says “In the name of Allaah, O Allaah, keep us away from the devil and keep the devil away from what You hast provided us.” It will be ordained that no devil will ever harm the child born to them}}
\hadithdefcmd{abudawud}{2162}{حَدَّثَنَا هَنَّادٌ، عَنْ وَكِيعٍ، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ الْحَارِثِ بْنِ مُخَلَّدٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَلْعُونٌ مَنْ أَتَى امْرَأَتَهُ فِي دُبُرِهَا ‏"‏ ‏.‏\hadithno{2162}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated AbuHurayrah: The Prophet (ﷺ) said: He who has intercourse with his wife through her anus is accursed}}
\hadithdefcmd{abudawud}{2163}{حَدَّثَنَا ابْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ، حَدَّثَنَا سُفْيَانُ، عَنْ مُحَمَّدِ بْنِ الْمُنْكَدِرِ، قَالَ سَمِعْتُ جَابِرًا، يَقُولُ إِنَّ الْيَهُودَ يَقُولُونَ إِذَا جَامَعَ الرَّجُلُ أَهْلَهُ فِي فَرْجِهَا مِنْ وَرَائِهَا كَانَ وَلَدُهُ أَحْوَلَ فَأَنْزَلَ اللَّهُ سُبْحَانَهُ وَتَعَالَى ‏\{‏ نِسَاؤُكُمْ حَرْثٌ لَكُمْ فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ ‏\}‏ ‏.‏\hadithno{2163}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (4528) Sahih Muslim (1435)}\hadithtrans{Muhammad bin Al Munkadir said I heard Jabir say The Jews used to say “When a man has intercourse with his wife through the vagina, but being on her back the child will have a squint, so the verse came down. Your wives are a tilth to you, so come to your tilth however you will.”}}
\hadithdefcmd{abudawud}{2164}{حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ يَحْيَى أَبُو الأَصْبَغِ، حَدَّثَنِي مُحَمَّدٌ، - يَعْنِي ابْنَ سَلَمَةَ - عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ أَبَانَ بْنِ صَالِحٍ، عَنْ مُجَاهِدٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِنَّ ابْنَ عُمَرَ - وَاللَّهُ يَغْفِرُ لَهُ - أَوْهَمَ إِنَّمَا كَانَ هَذَا الْحَىُّ مِنَ الأَنْصَارِ - وَهُمْ أَهْلُ وَثَنٍ - مَعَ هَذَا الْحَىِّ مِنْ يَهُودَ - وَهُمْ أَهْلُ كِتَابٍ - وَكَانُوا يَرَوْنَ لَهُمْ فَضْلاً عَلَيْهِمْ فِي الْعِلْمِ فَكَانُوا يَقْتَدُونَ بِكَثِيرٍ مِنْ فِعْلِهِمْ وَكَانَ مِنْ أَمْرِ أَهْلِ الْكِتَابِ أَنْ لاَ يَأْتُوا النِّسَاءَ إِلاَّ عَلَى حَرْفٍ وَذَلِكَ أَسْتَرُ مَا تَكُونُ الْمَرْأَةُ فَكَانَ هَذَا الْحَىُّ مِنَ الأَنْصَارِ قَدْ أَخَذُوا بِذَلِكَ مِنْ فِعْلِهِمْ وَكَانَ هَذَا الْحَىُّ مِنْ قُرَيْشٍ يَشْرَحُونَ النِّسَاءَ شَرْحًا مُنْكَرًا وَيَتَلَذَّذُونَ مِنْهُنَّ مُقْبِلاَتٍ وَمُدْبِرَاتٍ وَمُسْتَلْقِيَاتٍ فَلَمَّا قَدِمَ الْمُهَاجِرُونَ الْمَدِينَةَ تَزَوَّجَ رَجُلٌ مِنْهُمُ امْرَأَةً مِنَ الأَنْصَارِ فَذَهَبَ يَصْنَعُ بِهَا ذَلِكَ فَأَنْكَرَتْهُ عَلَيْهِ وَقَالَتْ إِنَّمَا كُنَّا نُؤْتَى عَلَى حَرْفٍ فَاصْنَعْ ذَلِكَ وَإِلاَّ فَاجْتَنِبْنِي حَتَّى شَرِيَ أَمْرُهُمَا فَبَلَغَ ذَلِكَ رَسُولَ اللَّهِ صلى الله عليه وسلم فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{‏ نِسَاؤُكُمْ حَرْثٌ لَكُمْ فَأْتُوا حَرْثَكُمْ أَنَّى شِئْتُمْ ‏\}‏ أَىْ مُقْبِلاَتٍ وَمُدْبِرَاتٍ وَمُسْتَلْقِيَاتٍ يَعْنِي بِذَلِكَ مَوْضِعَ الْوَلَدِ ‏.‏\hadithno{2164}\hadithgrade{Al-Albani: Hasan; Muhammad Muhyi Al-Din Abdul Hamid: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abdullah Ibn Abbas: Ibn Umar misunderstood (the Qur'anic verse, "So come to your tilth however you will")--may Allah forgive him. The fact is that this clan of the Ansar, who were idolaters, lived in the company of the Jews who were the people of the Book. They (the Ansar) accepted their superiority over themselves in respect of knowledge, and they followed most of their actions. The people of the Book (i.e. the Jews) used to have intercourse with their women on one side alone (i.e. lying on their backs). This was the most concealing position for (the vagina of) the women. This clan of the Ansar adopted this practice from them. But this tribe of the Quraysh used to uncover their women completely, and seek pleasure with them from in front and behind and laying them on their backs. When the muhajirun (the immigrants) came to Medina, a man married a woman of the Ansar. He began to do the same kind of action with her, but she disliked it, and said to him: We were approached on one side (i.e. lying on the back); do it so, otherwise keep away from me. This matter of theirs spread widely, and it reached the Messenger of Allah (ﷺ). So Allah, the Exalted, sent down the Qur'anic verse: "Your wives are a tilth to you, so come to your tilth however you will," i.e. from in front, from behind or lying on the back. But this verse meant the place of the delivery of the child, i.e. the vagina}}
\hadithdefcmd{abudawud}{2165}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا حَمَّادٌ، أَخْبَرَنَا ثَابِتٌ الْبُنَانِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ الْيَهُودَ، كَانَتْ إِذَا حَاضَتْ مِنْهُمُ امْرَأَةٌ أَخْرَجُوهَا مِنَ الْبَيْتِ وَلَمْ يُؤَاكِلُوهَا وَلَمْ يُشَارِبُوهَا وَلَمْ يُجَامِعُوهَا فِي الْبَيْتِ فَسُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنْ ذَلِكَ فَأَنْزَلَ اللَّهُ تَعَالَى ‏\{‏ يَسْأَلُونَكَ عَنِ الْمَحِيضِ قُلْ هُوَ أَذًى فَاعْتَزِلُوا النِّسَاءَ فِي الْمَحِيضِ ‏\}‏ إِلَى آخِرِ الآيَةِ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ جَامِعُوهُنَّ فِي الْبُيُوتِ وَاصْنَعُوا كُلَّ شَىْءٍ غَيْرَ النِّكَاحِ ‏"‏ ‏.‏ فَقَالَتِ الْيَهُودُ مَا يُرِيدُ هَذَا الرَّجُلُ أَنْ يَدَعَ شَيْئًا مِنْ أَمْرِنَا إِلاَّ خَالَفَنَا فِيهِ ‏.‏ فَجَاءَ أُسَيْدُ بْنُ حُضَيْرٍ وَعَبَّادُ بْنُ بِشْرٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالاَ يَا رَسُولَ اللَّهِ إِنَّ الْيَهُودَ تَقُولُ كَذَا وَكَذَا أَفَلاَ نَنْكِحُهُنَّ فِي الْمَحِيضِ فَتَمَعَّرَ وَجْهُ رَسُولِ اللَّهِ صلى الله عليه وسلم حَتَّى ظَنَنَّا ��َنْ قَدْ وَجِدَ عَلَيْهِمَا فَخَرَجَا فَاسْتَقْبَلَتْهُمَا هَدِيَّةٌ مِنْ لَبَنٍ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَبَعَثَ فِي آثَارِهِمَا فَسَقَاهُمَا فَظَنَنَّا أَنَّهُ لَمْ يَجِدْ عَلَيْهِمَا ‏.‏\hadithno{2165}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih}\hadithtrans{Anas bin Malik said Among the Jews when a woman menstruated, they did not eat with her and drink with her and did not associate with her in their houses, so the Apostle of Allaah(ﷺ) was questioned about it. Hence, Allah the Exalted revealed “And they ask you about menstruation,. Say “It is harmful, so keep aloof from women during menstruation till the end of the verse. The Apostle of Allaah(ﷺ) said “Associate with them in the houses and do everything except sexual intercourse. The Jews thereupon said “This man does not leave anything we do without opposing us in it. Usaid bin Hudair and Abbad bin Bishr came to the Apostle of Allaah(ﷺ) and said, Apostle of Allaah(ﷺ) the Jews are saying such and such. Shall we not have intercourse with them during their menstruation? The face of the Apostle of Allaah(ﷺ) underwent such a change that we thought he was angry with them, so they went out. They were met by a gift of milk which was being brought to the Apostle of Allaah(ﷺ) and he sent after them, whereby we felt that he was not angry with them}}
\hadithdefcmd{abudawud}{2166}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ جَابِرِ بْنِ صُبْحٍ، قَالَ سَمِعْتُ خِلاَسًا الْهَجَرِيَّ، قَالَ سَمِعْتُ عَائِشَةَ، - رضى الله عنها - تَقُولُ كُنْتُ أَنَا وَرَسُولُ اللَّهِ، صلى الله عليه وسلم نَبِيتُ فِي الشِّعَارِ الْوَاحِدِ وَأَنَا حَائِضٌ طَامِثٌ فَإِنْ أَصَابَهُ مِنِّي شَىْءٌ غَسَلَ مَكَانَهُ وَلَمْ يَعْدُهُ وَإِنْ أَصَابَ - تَعْنِي ثَوْبَهُ - مِنْهُ شَىْءٌ غَسَلَ مَكَانَهُ وَلَمْ يَعْدُهُ وَصَلَّى فِيهِ ‏.‏\hadithno{2166}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Aisha, Ummul Mu'minin: I and the Messenger of Allah (ﷺ) used to lie in one cloth at night while I was menstruating. If anything from me smeared him, he washed the same place (that was smeared), and did not wash beyond it. If anything from him smeared his clothe, he washed the same place and did not wash beyond that, and prayed with it (i.e. the clothe)}}
\hadithdefcmd{abudawud}{2167}{حَدَّثَنَا مُحَمَّدُ بْنُ الْعَلاَءِ، وَمُسَدَّدٌ، قَالاَ حَدَّثَنَا حَفْصٌ، عَنِ الشَّيْبَانِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ شَدَّادٍ، عَنْ خَالَتِهِ، مَيْمُونَةَ بِنْتِ الْحَارِثِ أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم كَانَ إِذَا أَرَادَ أَنْ يُبَاشِرَ امْرَأَةً مِنْ نِسَائِهِ وَهِيَ حَائِضٌ أَمَرَهَا أَنْ تَتَّزِرَ ثُمَّ يُبَاشِرُهَا ‏.‏\hadithno{2167}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Sahih Bukhari (303) Sahih Muslim (293)}\hadithtrans{Maimunah daughter of Al Harith said “When the Apostle of Allaah(ﷺ) intended to associate and lie with any of his wives who was menstruating, he ordered her to wrap up the lower garment(loin-cloth) and then he had association with her}}
\hadithdefcmd{abudawud}{2168}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا يَحْيَى، عَنْ شُعْبَةَ، - غَيْرُهُ عَنْ سَعِيدٍ، - حَدَّثَنِي الْحَكَمُ، عَنْ عَبْدِ الْحَمِيدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم فِي الَّذِي يَأْتِي امْرَأَتَهُ وَهِيَ حَائِضٌ قَالَ ‏ "‏ يَتَصَدَّقُ بِدِينَارٍ أَوْ بِنِصْفِ دِينَارٍ ‏"‏ ‏.‏\hadithno{2168}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: The Prophet (ﷺ) said about a man who has sexual intercourse with a menstruating woman: He should give one or half dinar as sadaqah}}
\hadithdefcmd{abudawud}{2169}{حَدَّثَنَا عَبْدُ السَّلاَمِ بْنُ مُطَهَّرٍ، حَدَّثَنَا جَعْفَرٌ، - يَعْنِي ابْنَ سُلَيْمَانَ - عَنْ عَلِيِّ بْنِ الْحَكَمِ الْبُنَانِيِّ، عَنْ أَبِي الْحَسَنِ الْجَزَرِيِّ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ إِذَا أَصَابَهَا فِي الدَّمِ فَدِينَارٌ وَإِذَا أَصَابَهَا فِي انْقِطَاعِ الدَّمِ فَنِصْفُ دِينَارٍ ‏.‏\hadithno{2169}\hadithgrade{Al-Albani: Sahih Muquf; Muhammad Muhyi Al-Din Abdul Hamid: Sahih Muquf; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abdullah ibn Abbas: If a man has sexual intercourse (with menstruating woman) during her bleeding, he should give one dinar as sadaqah, and if he does so when bleeding has stopped, he should give half a dinar as sadaqah}}
\hadithdefcmd{abudawud}{2170}{حَدَّثَنَا إِسْحَاقُ بْنُ إِسْمَاعِيلَ الطَّالْقَانِيُّ، حَدَّثَنَا سُفْيَانُ، عَنِ ابْنِ أَبِي نَجِيحٍ، عَنْ مُجَاهِدٍ، عَنْ قَزَعَةَ، عَنْ أَبِي سَعِيدٍ، ذُكِرَ ذَلِكَ عِنْدَ النَّبِيِّ صلى الله عليه وسلم - يَعْنِي الْعَزْلَ - قَالَ ‏"‏ فَلِمَ يَفْعَلُ أَحَدُكُمْ ‏"‏ ‏.‏ وَلَمْ يَقُلْ فَلاَ يَفْعَلْ أَحَدُكُمْ ‏"‏ فَإِنَّهُ لَيْسَتْ مِنْ نَفْسٍ مَخْلُوقَةٍ إِلاَّ اللَّهُ خَالِقُهَا ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ قَزَعَةُ مَوْلَى زِيَادٍ ‏.‏\hadithno{2170}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1438)}\hadithtrans{Abu Sa’id reported “The people mentioned about withdrawing the penis before the Prophet (ﷺ). He said “Why one of you does so? He did not say “One of you should not do so”. Every soul that is to be born, Allaah will create it. Abu Dawud said “Qaza’ah is a client of Ziyad”}}
\hadithdefcmd{abudawud}{2171}{حَدَّثَنَا مُوسَى بْنُ إِسْمَاعِيلَ، حَدَّثَنَا أَبَانُ، حَدَّثَنَا يَحْيَى، أَنَّ مُحَمَّدَ بْنَ عَبْدِ الرَّحْمَنِ بْنِ ثَوْبَانَ، حَدَّثَهُ أَنَّ رِفَاعَةَ حَدَّثَهُ عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَجُلاً، قَالَ يَا رَسُولَ اللَّهِ إِنَّ لِي جَارِيَةً وَأَنَا أَعْزِلُ عَنْهَا وَأَنَا أَكْرَهُ أَنْ تَحْمِلَ وَأَنَا أُرِيدُ مَا يُرِيدُ الرِّجَالُ وَإِنَّ الْيَهُودَ تُحَدِّثُ أَنَّ الْعَزْلَ مَوْءُودَةُ الصُّغْرَى ‏.‏ قَالَ ‏ "‏ كَذَبَتْ يَهُودُ لَوْ أَرَادَ اللَّهُ أَنْ يَخْلُقَهُ مَا اسْتَطَعْتَ أَنْ تَصْرِفَهُ ‏"‏ ‏.‏\hadithno{2171}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuSa'id al-Khudri: A man said: Messenger of Allah, I have a slave-girl and I withdraw the penis from her (while having intercourse), and I dislike that she becomes pregnant. I intend (by intercourse) what the men intend by it. The Jews say that withdrawing the penis (azl) is burying the living girls on a small scale. He (the Prophet) said: The Jews told a lie. If Allah intends to create it, you cannot turn it away}}
\hadithdefcmd{abudawud}{2172}{حَدَّثَنَا الْقَعْنَبِيُّ، عَنْ مَالِكٍ، عَنْ رَبِيعَةَ بْنِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنِ ابْنِ مُحَيْرِيزٍ، قَالَ دَخَلْتُ الْمَسْجِدَ فَرَأَيْتُ أَبَا سَعِيدٍ الْخُدْرِيَّ فَجَلَسْتُ إِلَيْهِ فَسَأَلْتُهُ عَنِ الْعَزْلِ، فَقَالَ أَبُو سَعِيدٍ خَرَجْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي غَزْوَةِ بَنِي الْمُصْطَلِقِ فَأَصَبْنَا سَبْيًا مِنْ سَبْىِ الْعَرَبِ فَاشْتَهَيْنَا النِّسَاءَ وَاشْتَدَّتْ عَلَيْنَا الْعُزْبَةُ وَأَحْبَبْنَا الْفِدَاءَ فَأَرَدْنَا أَنْ نَعْزِلَ ثُمَّ قُلْنَا نَعْزِلُ وَرَسُولُ اللَّهِ صلى الله عليه وسلم بَيْنَ أَظْهُرِنَا قَبْلَ أَنْ نَسْأَلَهُ عَنْ ذَلِكَ فَسَأَلْنَاهُ عَنْ ذَلِكَ فَقَالَ ‏ "‏ مَا عَلَيْكُمْ أَنْ لاَ تَفْعَلُوا مَا مِنْ نَسَمَةٍ كَائِنَةٍ إِلَى يَوْمِ الْقِيَامَةِ إِلاَّ وَهِيَ كَائِنَةٌ ‏"‏ ‏.‏\hadithno{2172}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari (2542) Sahih Muslim (1438)}\hadithtrans{Muhairiz said “I entered the mosque and saw Abu Sa’id Al Khudri . I sat with him and asked about withdrawing the penis (while having intercourse). Abu Sa’id said We went out with the Apostle of Allaah(ﷺ) on the expedition to Banu Al Mustaliq and took some Arab women captive and we desired the women for we were suffering from the absence of our wives and we wanted ransom, so we intended to withdraw the penis (while having intercourse with the slave women). But we asked ourselves “can we draw the penis when the Apostle of Allaah(ﷺ) is among us before asking him about it? So we asked him about it. He said “it does not matter if you do not do it, for very soul that is to be born up to the Day of Resurrection will be born.”}}
\hadithdefcmd{abudawud}{2173}{حَدَّثَنَا عُثْمَانُ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا الْفَضْلُ بْنُ دُكَيْنٍ، حَدَّثَنَا زُهَيْرٌ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ رَجُلٌ مِنَ الأَنْصَارِ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ إِنَّ لِي جَارِيَةً أَطُوفُ عَلَيْهَا وَأَنَا أَكْرَهُ أَنْ تَحْمِلَ ‏.‏ فَقَالَ ‏"‏ اعْزِلْ عَنْهَا إِنْ شِئْتَ فَإِنَّهُ سَيَأْتِيهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏ قَالَ فَلَبِثَ الرَّجُلُ ثُمَّ أَتَاهُ فَقَالَ إِنَّ الْجَارِيَةَ قَدْ حَمَلَتْ ‏.‏ قَالَ ‏"‏ قَدْ أَخْبَرْتُكَ أَنَّهُ سَيَأْتِيهَا مَا قُدِّرَ لَهَا ‏"‏ ‏.‏\hadithno{2173}\hadithgrade{Al-Albani: Sahih; Muhammad Muhyi Al-Din Abdul Hamid: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim (1439)}\hadithtrans{Jabir said “A man from the Ansar came to the Apostle of Allaah(ﷺ) and said “I have a slave girl and I have intercourse with her. But I dislike her to conceive. He replied “Withdraw your penis from her if you wish for what is decreed for her will come to her.” After a time the man came to him and said “The girl has become pregnant”. He said “I told you that what was decreed for her would come to her.”}}
\hadithdefcmd{abudawud}{2174}{حَدَّثَنَا مُسَدَّدٌ، حَدَّثَنَا بِشْرٌ، حَدَّثَنَا الْجُرَيْرِيُّ، ح وَحَدَّثَنَا مُؤَمَّلٌ، حَدَّثَنَا إِسْمَاعِيلُ، ح وَحَدَّثَنَا مُوسَى، حَدَّثَنَا حَمَّادٌ، كُلُّهُمْ عَنِ الْجُرَيْرِيِّ، عَنْ أَبِي نَضْرَةَ، حَدَّثَنِي شَيْخٌ، مِنْ طُفَاوَةَ قَالَ تَثَوَّيْتُ أَبَا هُرَيْرَةَ بِالْمَدِينَةِ فَلَمْ أَرَ رَجُلاً مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم أَشَدَّ تَشْمِيرًا وَلاَ أَقْوَمَ عَلَى ضَيْفٍ مِنْهُ فَبَيْنَمَا أَنَا عِنْدَهُ يَوْمًا وَهُوَ عَلَى سَرِيرٍ لَهُ وَمَعَهُ كِيسٌ فِيهِ حَصًى أَوْ نَوًى - وَأَسْفَلُ مِنْهُ جَارِيَةٌ لَهُ سَوْدَاءُ - وَهُوَ يُسَبِّحُ بِهَا حَتَّى إِذَا أَنْفَدَ مَا فِي الْكِيسِ أَلْقَاهُ إِلَيْهَا فَجَمَعَتْهُ فَأَعَادَتْهُ فِي الْكِيسِ فَدَفَعَتْهُ إِلَيْهِ فَقَالَ أَلاَ أُحَدِّثُكَ عَنِّي وَعَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ قُلْتُ بَلَى ‏.‏ قَالَ بَيْنَا أَنَا أُوعَكُ فِي الْمَسْجِدِ إِذْ جَاءَ رَسُولُ اللَّهِ صلى الله عليه وسلم حَتَّى دَخَلَ الْمَسْجِدَ ‏.‏ فَقَالَ ‏"‏ مَنْ أَحَسَّ الْفَتَى الدَّوْسِيَّ ‏"‏ ‏.‏ ثَلاَثَ مَرَّاتٍ ‏.‏ فَقَالَ رَجُلٌ يَا رَسُولَ اللَّهِ هُوَ ذَا يُوعَكُ فِي جَانِبِ الْمَسْجِدِ فَأَقْبَلَ يَمْشِي حَتَّى انْتَهَى إِلَىَّ فَوَضَعَ يَدَهُ عَلَىَّ فَقَالَ لِي مَعْرُوفًا فَنَهَضْتُ فَانْطَلَقَ يَمْشِي حَتَّى أَتَى مَقَامَهُ الَّذِي يُصَلِّي فِيهِ فَأَقْبَلَ عَلَيْهِمْ وَمَعَهُ صَفَّانِ مِنْ رِجَالٍ وَصَفٌّ مِنْ نِسَاءٍ أَوْ صَفَّانِ مِنْ نِسَاءٍ وَصَفٌّ مِنْ رِجَالٍ فَقَالَ ‏"‏ إِنْ أَنْسَانِي الشَّيْطَانُ شَيْئًا مِنْ صَلاَتِي فَلْيُسَبِّحِ الْقَوْمُ وَلْيُصَفِّقِ النِّسَاءُ ‏"‏ ‏.‏ قَالَ فَصَلَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَلَمْ يَنْسَ مِنْ صَلاَتِهِ شَيْئًا ‏.‏ فَقَالَ ‏"‏ مَجَالِسَكُمْ مَجَالِسَكُمْ ‏"‏ ‏.‏ زَادَ مُوسَى ‏"‏ هَا هُنَا ‏"‏ ‏.‏ ثُمَّ حَمِدَ اللَّهَ تَعَالَى وَأَثْنَى عَلَيْهِ ثُمَّ قَالَ ‏"‏ أَمَّا بَعْدُ ‏"‏ ‏.‏ ثُمَّ اتَّفَقُوا ثُمَّ أَقْبَلَ عَلَى الرِّجَالِ فَقَالَ ‏"‏ هَلْ مِنْكُمُ الرَّجُلُ إِذَا أَتَى أَهْلَهُ فَأَغْلَقَ عَلَيْهِ بَابَهُ وَأَلْقَى عَلَيْهِ سِتْرَهُ وَاسْتَتَرَ بِسِتْرِ اللَّهِ ‏"‏ ‏.‏ قَالُوا نَعَمْ ‏.‏ قَالَ ‏"‏ ثُمَّ يَجْلِسُ بَعْدَ ذَلِكَ فَيَقُولُ فَعَلْتُ كَذَا فَعَلْتُ كَذَا ‏"‏ ‏.‏ قَالَ فَسَكَتُوا قَالَ فَأَقْبَلَ عَلَى النِّسَاءِ فَقَالَ ‏"‏ هَلْ مِنْكُنَّ مَنْ تُحَدِّثُ ‏"‏ ‏.‏ فَسَكَتْنَ فَجَثَتْ فَتَاةٌ - قَالَ مُؤَمَّلٌ فِي حَدِيثِهِ فَتَاةٌ كَعَابٌ - عَلَى إِحْدَى رُكْبَتَيْهَا وَتَطَاوَلَتْ لِرَسُولِ اللَّهِ صلى الله عليه وسلم لِيَرَاهَا وَيَسْمَعَ كَلاَمَهَا فَقَالَتْ يَا رَسُولَ اللَّهِ إِنَّهُمْ لَيَتَحَدَّثُونَ وَإِنَّهُنَّ لَيَتَحَدَّثْنَهْ فَقَالَ ‏"‏ هَلْ تَدْرُونَ مَا مَثَلُ ذَلِكَ ‏"‏ ‏.‏ فَقَالَ ‏"‏ إِنَّمَا ذَلِكَ مَثَلُ شَيْطَانَةٍ لَقِيَتْ شَيْطَانًا فِي السِّكَّةِ فَقَضَى مِنْهَا حَاجَتَهُ وَالنَّاسُ يَنْظُرُونَ إِلَيْهِ أَلاَ وَإِنَّ طِيبَ الرِّجَالِ مَا ظَهَرَ رِيحُهُ وَلَمْ يَظْهَرْ لَوْنُهُ أَلاَ إِنَّ طِيبَ النِّسَاءِ مَا ظَهَرَ لَوْنُهُ وَلَمْ يَظْهَرْ رِيحُهُ ‏"‏ ‏.‏ قَالَ أَبُو دَاوُدَ مِنْ هَا هُنَا حَفِظْتُهُ عَنْ مُؤَمَّلٍ وَمُوسَى ‏"‏ أَلاَ لاَ يُفْضِيَنَّ رَجُلٌ إِلَى رَجُلٍ وَلاَ امْرَأَةٌ إِلَى امْرَأَةٍ إِلاَّ إِلَى وَلَدٍ أَوْ وَالِدٍ ‏"‏ ‏.‏ وَذَكَرَ ثَالِثَةً فَأُنْسِيتُهَا وَهُوَ فِي حَدِيثِ مُسَدَّدٍ وَلَكِنِّي لَمْ أُتْقِنْهُ كَمَا أُحِبُّ وَقَالَ مُوسَى حَدَّثَنَا حَمَّادٌ عَنِ الْجُرَيْرِيِّ عَنْ أَبِي نَضْرَةَ عَنِ الطُّفَاوِيِّ ‏.‏\hadithno{2174}\hadithgrade{Al-Albani: Daif; Muhammad Muhyi Al-Din Abdul Hamid: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated AbuHurayrah: AbuNadrah reported: An old man of Tufawah said to me: I was a guest of AbuHurayrah at Medina. I did not find any one of the companions of the Prophet (ﷺ) more devoted to worship and more hospitable than AbuHurayrah. One day I was with him when he was sitting on his bed. He had a purse which contained pebbles or kernels. A black slave-girl of his was sitting below. Counting them he was glorifying Allah. When the pebbles or the kernels in the purse were finished, she gathered them and put them again in the purse, and gave it to him. He said: Should I not tell you about me and about the Messenger of Allah (ﷺ)? I said: Yes. He said: Once when I was laid up with fever in the mosque, the Messenger of Allah (ﷺ) came and entered the mosque, and said: Who saw the youth of ad-Daws. He said this three times. A man said: Messenger of Allah, there he is, laid up with fever on one side of the mosque. He moved, walking forward till he reached me. He placed his hand on me. He had a kind talk with me, and I rose. He then began to walk till he reached the place where he used to offer his prayer. He paid his attention to the people. There were two rows of men and one row of women, or two rows of women and one row of men (the narrator is doubtful). He then said: If Satan makes me forget anything during the prayer, the men should glorify Allah, and the women should clap their hands. The Messenger of Allah (ﷺ) then prayed and he did not forget anything during the prayer. He said: Be seated in your places, be seated in your places. The narrator, Musa, added the word "here". He then praised Allah and exalted Him, and said: Now to our topic. The agreed version begins: He then said: Is there any man among you who approaches his wife, closes the door, covers himself with a curtain, and he is concealed with the curtain of Allah? They replied: Yes. He said: later he sits and says: I did so-and-so; I did so-and-so. The people kept silence. He then turned to the women and said (to them): Is there any woman among you who narrates it? They kept silence. Then a girl fell on one of her knees. The narrator, Mu'ammil, said in his version: a buxom girl. She raised her head before the Messenger of Allah (ﷺ) so that he could see her and listen to her. She said: Messenger of Allah, they (the men) describe the secrets (of intercourse) and they (the women) also describe the secrets (of intercourse) to the people. He said: Do you know what the similitude is? He said: The likeness of this act is the likeness of a female Satan who meets the male Satan on the roadside; he fulfils his desire with her while the people are looking at him. Beware! The perfume of men is that whose smell becomes visible and its colour does not appear. Beware! The perfume of women is that whose colour becomes visible and whose smell is not obvious. AbuDawud said: From here I remembered this tradition from Mu'ammil and Musa: Beware! No man should lie with another man, no woman should lie with another woman except with one's child or father. He also mentioned a third which I have forgotten. This has been mentioned in the version of Musaddad, but I do not remember it as precisely as I like. The narrator, Musa, said: Hammad narrated this tradition from al-Jarir from AbuNadrah from at-Tufawi}}
